@@ -5,7 +5,6 @@ import utool as ut
 # import logging
 import itertools as it
 import copy
-import six
 import collections
 from wbia import constants as const
 from wbia.algo.graph import nx_dynamic_graph
@@ -27,6 +26,8 @@ from wbia.algo.graph.state import UNINFERABLE
 from wbia.algo.graph.state import SAME, DIFF, NULL
 import networkx as nx
 import logging
+import threading
+
 
 print, rrr, profile = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
@@ -233,7 +234,7 @@ class Feedback(object):
         if decision == UNREV:
             # Unreviewing an edge deletes anything not yet committed
             if edge in infr.external_feedback:
-                raise ValueError('External edge reviews cannot be undone')
+                logger.warning('External edge reviews cannot be undone')
             if edge in infr.internal_feedback:
                 del infr.internal_feedback[edge]
 
@@ -291,7 +292,58 @@ class Feedback(object):
                 infr.refresh.add(meaningful, user_id, decision)
 
         if infr.test_mode:
-            infr.metrics_list.append(infr.measure_metrics())
+            metrics = infr.measure_metrics()
+            infr.metrics_list.append(metrics)
+
+            try:
+                from wbia_lca._plugin import get_ggr_stats, LOG_DECISION_FILE
+
+                valid_aids = list(sorted(infr.aids))
+                components = list(infr.positive_components())
+                component_aids = ut.flatten(components)
+                assert len(set(component_aids) ^ set(valid_aids)) == 0
+
+                aid_to_nids = {}
+                for index, component in enumerate(components):
+                    for aid in component:
+                        assert aid not in aid_to_nids
+                        aid_to_nids[aid] = index
+
+                valid_nids = ut.take(aid_to_nids, valid_aids)
+
+                ggr_name_dates_stats = get_ggr_stats(
+                    infr.ibs,
+                    valid_aids,
+                    valid_nids,
+                )
+                with open(LOG_DECISION_FILE, 'a') as logfile:
+                    data = (
+                        len(infr.metrics_list),
+                        len(set(valid_nids)),
+                        ggr_name_dates_stats['GGR-16 D1 OR D2'],
+                        ggr_name_dates_stats['GGR-16 PL INDEX'],
+                        ggr_name_dates_stats['GGR-16 PL CI'],
+                        ggr_name_dates_stats['2016/01/30'],
+                        ggr_name_dates_stats['2016/01/31'],
+                        ggr_name_dates_stats['GGR-16 D1 AND D2'],
+                        ggr_name_dates_stats['GGR-16 COVERAGE'],
+                        ggr_name_dates_stats['GGR-18 D1 OR D2'],
+                        ggr_name_dates_stats['GGR-18 PL INDEX'],
+                        ggr_name_dates_stats['GGR-18 PL CI'],
+                        ggr_name_dates_stats['2018/01/27'],
+                        ggr_name_dates_stats['2018/01/28'],
+                        ggr_name_dates_stats['GGR-18 D1 AND D2'],
+                        ggr_name_dates_stats['GGR-18 COVERAGE'],
+                        ggr_name_dates_stats['GGR-16 AND GGR-18'],
+                        metrics['n_algo'],
+                        metrics['n_manual'],
+                        len(infr.queue),
+                    )
+                    line = ','.join(map(str, data))
+                    logger.info('Progress: %s' % (line,))
+                    logfile.write('%s\n' % (line,))
+            except Exception:
+                pass
 
         infr.verbose = prev_verbose
 
@@ -416,10 +468,8 @@ class Feedback(object):
         return vals[-1]
 
     def all_feedback_items(infr):
-        for edge, vals in six.iteritems(infr.external_feedback):
-            yield edge, vals
-        for edge, vals in six.iteritems(infr.internal_feedback):
-            yield edge, vals
+        yield from infr.external_feedback.items()
+        yield from infr.internal_feedback.items()
 
     def all_feedback(infr):
         all_feedback = ut.ddict(list)
@@ -557,7 +607,7 @@ class NameRelabel(object):
         unknown_labels = ut.compress(unique_newlabels, still_unknown)
 
         new_flags = [n is None for n in new_names]
-        #     isinstance(n, six.string_types) and n.startswith('_extra_name')
+        #     isinstance(n, str) and n.startswith('_extra_name')
         #     for n in new_names
         # ]
         label_to_name = ut.dzip(unique_newlabels, new_names)
@@ -1026,7 +1076,7 @@ class AltConstructors(object):
             # )
 
 
-@six.add_metaclass(ut.ReloadingMetaclass)
+@ut.reloadable_class
 class AnnotInference(
     ut.NiceRepr,
     # Old internal stuffs
@@ -1172,7 +1222,7 @@ class AnnotInference(
         # wbia controller and initial nodes
         # TODO: aids can be abstracted as a property that simply looks at the
         # nodes in infr.graph.
-        if isinstance(ibs, six.string_types):
+        if isinstance(ibs, str):
             import wbia
 
             ibs = wbia.opendb(ibs)
@@ -1261,6 +1311,7 @@ class AnnotInference(
 
         # A generator that maintains the state of the algorithm
         infr._gen = None
+        infr._gen_lock = threading.Lock()
 
         # Computer vision algorithms
         infr.ranker = None
@@ -1270,13 +1321,39 @@ class AnnotInference(
         # TODO: move to params
         infr.task_thresh_dict = {
             'zebra_grevys': {
+                # 'match_state': {
+                #     POSTV: 0.7732,  # GGR2 - 0.7732, Kaia CA - 0.7312
+                #     NEGTV: 0.8605,  # GGR2 - 0.8605, Kaia CA - 0.8892
+                #     INCMP: np.inf,
+                # },
+                # 'match_state': {
+                #     POSTV: 0.8062,  # NAMED ANNOTS
+                #     NEGTV: 0.8538,  # NAMED ANNOTS
+                #     INCMP: np.inf,
+                # },
                 'match_state': {
-                    POSTV: 0.7732,  # GGR2 - 0.7732, Kaia CA - 0.7312
-                    NEGTV: 0.8605,  # GGR2 - 0.8605, Kaia CA - 0.8892
+                    POSTV: 0.6291,  # CA
+                    NEGTV: 0.8695,  # CA
                     INCMP: np.inf,
                 },
                 'photobomb_state': {'pb': np.inf, 'nopb': np.inf},
             },
+            'zebra_grevys+_canonical_': {
+                'match_state': {
+                    POSTV: 0.5305,  # CA Region
+                    NEGTV: 0.8496,  # CA Region
+                    INCMP: np.inf,
+                },
+                'photobomb_state': {'pb': np.inf, 'nopb': np.inf},
+            },
+            'zebra_mountain': {
+                'match_state': {
+                    POSTV: 0.7767,
+                    NEGTV: 0.8640,
+                    INCMP: 0.8375,
+                },
+                'photobomb_state': {'pb': np.inf, 'nopb': np.inf},
+            },
             'zebra_plains': {
                 'match_state': {POSTV: np.inf, NEGTV: np.inf, INCMP: np.inf},
                 'photobomb_state': {'pb': np.inf, 'nopb': np.inf},
@@ -1378,7 +1455,7 @@ class AnnotInference(
         infr.print('__init__ autoinit', level=1)
         if autoinit:
             infr.initialize_graph()
-            if isinstance(autoinit, six.string_types):
+            if isinstance(autoinit, str):
                 infr.reset_feedback(autoinit)
         infr.print('__init__ done', level=1)
 
