@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 import logging
-import six
 import numpy as np
 import utool as ut
 import ubelt as ub
@@ -80,28 +79,25 @@ class InfrLoops(object):
         infr.init_refresh()
 
         infr.phase = 0
+        infr.print('Entering Phase 0', 1, color='red')
         # Phase 0.1: Ensure the user sees something immediately
         if infr.params['algo.quickstart']:
             infr.loop_phase = 'quickstart_init'
             # quick startup. Yield a bunch of random edges
             num = infr.params['manual.n_peek']
-            user_request = []
             for edge in ut.random_combinations(infr.aids, 2, num=num):
-                user_request += [infr._make_review_tuple(edge, None)]
-                yield user_request
+                yield infr._make_review_tuple(edge, None)
 
         if infr.params['algo.hardcase']:
             infr.loop_phase = 'hardcase_init'
             # Check previously labeled edges that where the groundtruth and the
             # verifier disagree.
-            for _ in infr.hardcase_review_gen():
-                yield _
+            yield from infr.hardcase_review_gen()
 
         if infr.params['inference.enabled']:
             infr.loop_phase = 'incon_recover_init'
             # First, fix any inconsistencies
-            for _ in infr.incon_recovery_gen():
-                yield _
+            yield from infr.incon_recovery_gen()
 
         # Phase 0.2: Ensure positive redundancy (this is generally quick)
         # so the user starts seeing real work after one random review is made
@@ -109,18 +105,17 @@ class InfrLoops(object):
         if infr.params['redun.enabled'] and infr.params['redun.enforce_pos']:
             infr.loop_phase = 'pos_redun_init'
             # Fix positive redundancy of anything within the loop
-            for _ in infr.pos_redun_gen():
-                yield _
+            yield from infr.pos_redun_gen()
 
         infr.phase = 1
+        infr.print('Entering Phase 1', 1, color='red')
         if infr.params['ranking.enabled']:
             for count in it.count(0):
                 infr.print('Outer loop iter %d ' % (count,))
 
                 # Phase 1: Try to merge PCCs by searching for LNBNN candidates
                 infr.loop_phase = 'ranking_{}'.format(count)
-                for _ in infr.ranked_list_gen(use_refresh):
-                    yield _
+                yield from infr.ranked_list_gen(use_refresh)
 
                 terminate = infr.refresh.num_meaningful == 0
                 if terminate:
@@ -128,11 +123,11 @@ class InfrLoops(object):
 
                 # Phase 2: Ensure positive redundancy.
                 infr.phase = 2
+                infr.print('Entering Phase 2', 1, color='red')
                 infr.loop_phase = 'posredun_{}'.format(count)
                 if all(ut.take(infr.params, ['redun.enabled', 'redun.enforce_pos'])):
                     # Fix positive redundancy of anything within the loop
-                    for _ in infr.pos_redun_gen():
-                        yield _
+                    yield from infr.pos_redun_gen()
 
                 logger.info('prob_any_remain = %r' % (infr.refresh.prob_any_remain(),))
                 logger.info(
@@ -150,22 +145,23 @@ class InfrLoops(object):
                     break
 
         infr.phase = 3
+        infr.print('Entering Phase 3', 1, color='red')
         # Phase 0.3: Ensure positive redundancy (this is generally quick)
         if all(ut.take(infr.params, ['redun.enabled', 'redun.enforce_neg'])):
             # Phase 3: Try to automatically acheive negative redundancy without
             # asking the user to do anything but resolve inconsistency.
-            infr.print('Entering phase 3', 1, color='red')
             infr.loop_phase = 'negredun'
-            for _ in infr.neg_redun_gen():
-                yield _
+            yield from infr.neg_redun_gen()
 
         infr.phase = 4
-        infr.print('Terminate', 1, color='red')
+        infr.print('Phase 4 - Terminate', 1, color='red')
         infr.print('Exiting main loop')
 
         if infr.params['inference.enabled']:
             infr.assert_consistency_invariant()
 
+        return 'finished:main'
+
     def hardcase_review_gen(infr):
         """
         Subiterator for hardcase review
@@ -220,8 +216,7 @@ class InfrLoops(object):
         # work around add_candidate_edges
         infr.prioritize(metric='hardness', edges=edges, scores=hardness)
         infr.set_edge_attrs('hardness', ut.dzip(edges, hardness))
-        for _ in infr._inner_priority_gen(use_refresh=False):
-            yield _
+        yield from infr._inner_priority_gen(use_refresh=False)
 
     def ranked_list_gen(infr, use_refresh=True):
         """
@@ -237,8 +232,7 @@ class InfrLoops(object):
             return
         if use_refresh:
             infr.refresh.clear()
-        for _ in infr._inner_priority_gen(use_refresh):
-            yield _
+        yield from infr._inner_priority_gen(use_refresh)
 
     def incon_recovery_gen(infr):
         """
@@ -259,8 +253,7 @@ class InfrLoops(object):
         infr.print('--- INCON RECOVER LOOP ---', color='white')
         infr.queue.clear()
         infr.add_candidate_edges(maybe_error_edges)
-        for _ in infr._inner_priority_gen(use_refresh=False):
-            yield _
+        yield from infr._inner_priority_gen(use_refresh=False)
 
     def pos_redun_gen(infr):
         """
@@ -285,21 +278,14 @@ class InfrLoops(object):
         def thread_gen():
             # This is probably not safe
             new_edges = infr.find_pos_redun_candidate_edges()
-            for new_edges in buffered_add_candidate_edges(infr, 50, new_edges):
-                yield new_edges
+            yield from buffered_add_candidate_edges(infr, 50, new_edges)
 
         def serial_gen():
             # use this if threading does bad things
-            if True:
-                new_edges = list(infr.find_pos_redun_candidate_edges())
-                if len(new_edges) > 0:
-                    infr.add_candidate_edges(new_edges)
-                    yield new_edges
-            else:
-                for new_edges in ub.chunks(infr.find_pos_redun_candidate_edges(), 100):
-                    if len(new_edges) > 0:
-                        infr.add_candidate_edges(new_edges)
-                        yield new_edges
+            new_edges = list(infr.find_pos_redun_candidate_edges())
+            if len(new_edges) > 0:
+                infr.add_candidate_edges(new_edges)
+                yield new_edges
 
         def filtered_gen():
             # Buffer one-vs-one scores in the background and present an edge to
@@ -310,13 +296,13 @@ class InfrLoops(object):
             #     candgen = thread_gen()
 
             include_filter_set = None
-            if PRINCETON_KAIA_EDGE_LIST is not None:
+            if False and PRINCETON_KAIA_EDGE_LIST is not None:
                 # logger.info('[mixin_loops] FILTERING EDGES FOR KAIA')
                 # Sanity check, make sure that one of the edges is in the tier 1 dataset
                 include_filter_set = set(PRINCETON_KAIA_EDGE_LIST)
 
             for new_edges in candgen:
-                if infr.ibs is not None:
+                if False and infr.ibs is not None:
                     ibs = infr.ibs
                     qual_edges = ibs.unflat_map(ibs.get_annot_quality_int, new_edges)
                     valid_edges = []
@@ -342,13 +328,26 @@ class InfrLoops(object):
             infr.print('check pos-redun iter {}'.format(count))
             infr.queue.clear()
 
+            # if count > 0 and count % 5 == 0:
+            #     nid = infr._reset_inconsistency_reviews()
+            #     infr.print(
+            #         'Failed to fix inconsistency, reset reviews for NID = %r' % (nid,)
+            #     )
+            #     infr.reset_feedback('staging', apply=True)
+            #     infr.ensure_mst()
+            #     infr.apply_nondynamic_update()
+
             found_any = False
 
-            for new_edges in filtered_gen():
-                found_any = True
-                gen = infr._inner_priority_gen(use_refresh=False)
-                for value in gen:
-                    yield value
+            try:
+                for new_edges in filtered_gen():
+                    found_any = True
+                    yield from infr._inner_priority_gen(use_refresh=False)
+            except (RuntimeError, StopIteration):
+                logger.info(
+                    'StopIteration in pos_redun_gen, found_any = {!r}'.format(found_any)
+                )
+                break
 
             # logger.info('found_any = {!r}'.format(found_any))
             if not found_any:
@@ -378,9 +377,7 @@ class InfrLoops(object):
             infr.print('another neg redun chunk')
             # Add chunks in a little at a time for faster response time
             infr.add_candidate_edges(new_edges)
-            gen = infr._inner_priority_gen(use_refresh=False, only_auto=only_auto)
-            for value in gen:
-                yield value
+            yield from infr._inner_priority_gen(use_refresh=False, only_auto=only_auto)
 
     def _inner_priority_gen(infr, use_refresh=False, only_auto=False):
         """
@@ -431,9 +428,17 @@ class InfrLoops(object):
                 break
 
             # Try to automatically do the next review.
-            edge, priority = infr.peek()
-            infr.print('next_review. edge={}'.format(edge), 100)
+            try:
+                edge, priority = infr.peek()
+            except TypeError:
+                infr.print(
+                    'Nothing to peek',
+                    1,
+                    color='yellow',
+                )
+                break
 
+            infr.print('next_review. edge={}'.format(edge), 100)
             inconsistent = infr.is_recovering(edge)
 
             feedback = None
@@ -457,8 +462,7 @@ class InfrLoops(object):
                         infr.add_feedback(edge, priority=priority, **feedback)
                     else:
                         # Yield to the user if we need to pause
-                        user_request = infr.emit_manual_review(edge, priority)
-                        yield user_request
+                        yield infr.emit_manual_review(edge, priority)
 
         if infr.metrics_list:
             infr._print_previous_loop_statistics(count)
@@ -480,9 +484,13 @@ class InfrLoops(object):
         or assert not any(infr.main_gen())
         maybe this is fine.
         """
+        raise RuntimeError()
         infr.start_id_review(max_loops=max_loops, use_refresh=use_refresh)
         # To automatically run through the loop just exhaust the generator
-        result = next(infr._gen)
+        try:
+            result = next(infr._gen)
+        except StopIteration:
+            pass
         assert result is None, 'need user interaction. cannot auto loop'
         infr._gen = None
 
@@ -590,13 +598,10 @@ class InfrReviewers(object):
         # The first is the most important
         user_request = []
         user_request += [infr._make_review_tuple(edge, priority)]
-        try:
-            for edge_, priority in infr.peek_many(infr.params['manual.n_peek']):
-                if edge == edge_:
-                    continue
-                user_request += [infr._make_review_tuple(edge_, priority)]
-        except TypeError:
-            pass
+        for edge_, priority in infr.peek_many(infr.params['manual.n_peek']):
+            if edge == edge_:
+                continue
+            user_request += [infr._make_review_tuple(edge_, priority)]
 
         # If registered, send the request via a callback.
         request_review = infr.callbacks.get('request_review', None)
@@ -628,19 +633,20 @@ class InfrReviewers(object):
         if infr.params['manual.autosave']:
             infr.write_wbia_staging_feedback()
 
-    def continue_review(infr):
-        infr.print('continue_review', 10)
-        if infr._gen is None:
-            return None
-        try:
-            user_request = next(infr._gen)
-        except StopIteration:
-            review_finished = infr.callbacks.get('review_finished', None)
-            if review_finished is not None:
-                review_finished()
-            infr._gen = None
-            user_request = None
-        return user_request
+    def resume(infr):
+        with infr._gen_lock:
+            infr.print('continue_review', 10)
+            if infr._gen is None:
+                return 'finished:stopped'
+            try:
+                user_request = next(infr._gen)
+            except StopIteration:
+                review_finished = infr.callbacks.get('review_finished', None)
+                if review_finished is not None:
+                    review_finished()
+                infr._gen = None
+                user_request = 'finished:stopiteration'
+            return user_request
 
     def qt_edge_reviewer(infr, edge=None):
         import wbia.guitool as gt
@@ -682,7 +688,7 @@ class InfrReviewers(object):
             >>> gt.qtapp_loop(qwin=win, freq=10)
         """
         infr.qt_edge_reviewer()
-        # infr.continue_review()
+        # infr.resume()
         return infr.manual_wgt
 
 
@@ -692,7 +698,7 @@ if False:
 
     _sentinel = object()
 
-    class _background_consumer(Thread):
+    class _background_consumer(Thread):  # NOQA
         """
         Will fill the queue with content of the source in a separate thread.
 
@@ -741,7 +747,7 @@ if False:
             # Signal the consumer we are done.
             self._queue.put(_sentinel)
 
-    class buffered_add_candidate_edges(object):
+    class buffered_add_candidate_edges(object):  # NOQA
         """
         Buffers content of an iterator polling the contents of the given
         iterator in a separate thread.
@@ -754,10 +760,8 @@ if False:
         """
 
         def __init__(self, infr, size, source):
-            if six.PY2:
-                from Queue import Queue
-            else:
-                from queue import Queue
+            from queue import Queue
+
             self._queue = Queue(size)
 
             self._poller = _background_consumer(infr, self._queue, source)
@@ -770,7 +774,7 @@ if False:
         def __next__(self):
             item = self._queue.get(True)
             if item is _sentinel:
-                raise StopIteration()
+                return
             return item
 
         next = __next__
