@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 import logging
-import six
 import numpy as np
 import utool as ut
 import pandas as pd
@@ -11,12 +10,93 @@ from os.path import join  # NOQA
 from wbia.algo.graph import nx_utils as nxu
 from wbia.algo.graph.nx_utils import e_
 from wbia.algo.graph.state import POSTV, NEGTV, INCMP, UNREV  # NOQA
+from concurrent import futures
+import tqdm
+
 
 print, rrr, profile = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
 
 
-@six.add_metaclass(ut.ReloadingMetaclass)
+def _cm_breaking_worker(cm_list, review_cfg={}, scoring='annot'):
+
+    ranks_top = review_cfg.get('ranks_top', None)
+    ranks_bot = review_cfg.get('ranks_bot', None)
+
+    # Construct K-broken graph
+    edges = []
+
+    if ranks_bot is None:
+        ranks_bot = 0
+
+    scoring = scoring.lower()
+    assert scoring in ['annot', 'name']
+    assert ranks_bot == 0
+
+    for count, cm in enumerate(cm_list):
+        score_list = cm.annot_score_list
+
+        # rank_list = ut.argsort(score_list)[::-1]
+        # sortx = ut.argsort(rank_list)
+
+        # top_sortx = sortx[:ranks_top]
+        # bot_sortx = sortx[len(sortx) - ranks_bot :]
+        # short_sortx = ut.unique(top_sortx + bot_sortx)
+        # daid_list = ut.take(cm.daid_list, short_sortx)
+
+        values = sorted(zip(score_list, cm.daid_list))[::-1]
+        keep = values[:ranks_top]
+        daid_list = ut.take_column(keep, 1)
+        for daid in daid_list:
+            u, v = (cm.qaid, daid)
+            if v < u:
+                u, v = v, u
+            edges.append((u, v))
+    return edges
+
+
+def _make_rankings_worker(args):
+    import wbia  # NOQA
+    import tqdm  # NOQA
+
+    (
+        dbdir,
+        qaids_chunk,
+        daids,
+        cfgdict,
+        custom_nid_lookup,
+        verbose,
+        use_cache,
+        invalidate_supercache,
+        ranks_top,
+    ) = args
+
+    ibs = wbia.opendb(dbdir=dbdir)
+
+    edges = set([])
+    for qaids in tqdm.tqdm(qaids_chunk):
+
+        qreq_ = ibs.new_query_request(
+            [qaids],
+            daids,
+            cfgdict=cfgdict,
+            custom_nid_lookup=custom_nid_lookup,
+            verbose=verbose,
+        )
+
+        cm_list = qreq_.execute(
+            prog_hook=None,
+            use_cache=use_cache,
+            invalidate_supercache=False,
+        )
+
+        new_edges = set(_cm_breaking_worker(cm_list, review_cfg={'ranks_top': ranks_top}))
+        edges = edges | new_edges
+
+    return edges
+
+
+@ut.reloadable_class
 class AnnotInfrMatching(object):
     """
     Methods for running matching algorithms
@@ -32,12 +112,14 @@ class AnnotInfrMatching(object):
         name_method='node',
         use_cache=True,
         invalidate_supercache=False,
+        batch_size=None,
+        ranks_top=5,
     ):
         """
         Loads chip matches into the inference structure
         Uses graph name labeling and ignores wbia labeling
         """
-        infr._make_rankings(
+        return infr._make_rankings(
             qaids,
             daids,
             prog_hook,
@@ -45,6 +127,8 @@ class AnnotInfrMatching(object):
             name_method,
             use_cache=use_cache,
             invalidate_supercache=invalidate_supercache,
+            batch_size=batch_size,
+            ranks_top=ranks_top,
         )
 
     def _set_vsmany_info(infr, qreq_, cm_list):
@@ -62,6 +146,8 @@ class AnnotInfrMatching(object):
         name_method='node',
         use_cache=None,
         invalidate_supercache=None,
+        batch_size=None,
+        ranks_top=5,
     ):
         # from wbia.algo.graph import graph_iden
 
@@ -99,29 +185,102 @@ class AnnotInfrMatching(object):
             custom_nid_lookup = None
         else:
             raise KeyError('Unknown name_method={}'.format(name_method))
+        verbose = infr.verbose >= 2
 
-        qreq_ = ibs.new_query_request(
-            qaids,
-            daids,
-            cfgdict=cfgdict,
-            custom_nid_lookup=custom_nid_lookup,
-            verbose=infr.verbose >= 2,
-        )
+        # <HACK FOR PIE V2>
+        if cfgdict.get('pipeline_root', None) in ['PieTwo']:
+            from wbia_pie_v2._plugin import distance_to_score
 
-        # cacher = qreq_.get_big_cacher()
-        # if not cacher.exists():
-        #     pass
-        #     # import sys
-        #     # sys.exit(1)
+            globals().update(locals())
 
-        cm_list = qreq_.execute(
-            prog_hook=prog_hook,
-            use_cache=use_cache,
-            invalidate_supercache=invalidate_supercache,
-        )
-        infr._set_vsmany_info(qreq_, cm_list)
+            edges = []
+
+            for qaid in tqdm.tqdm(qaids):
+                daids_ = list(set(daids) - set([qaid]))
+                pie_annot_distances = ibs.pie_v2_predict_light_distance(
+                    qaid,
+                    daids_,
+                )
+                score_list = [
+                    distance_to_score(pie_annot_distance, norm=500.0)
+                    for pie_annot_distance in pie_annot_distances
+                ]
+                values = sorted(zip(score_list, daids_))[::-1]
+                keep = values[:ranks_top]
+                daid_list = ut.take_column(keep, 1)
+                for daid in daid_list:
+                    u, v = (qaid, daid)
+                    if v < u:
+                        u, v = v, u
+                    edges.append((u, v))
+
+            edges = set(edges)
+            return edges
+        # </HACK>
+
+        if batch_size is not None:
+            qaids_chunks = list(ut.ichunks(qaids, batch_size))
+            num_chunks = len(qaids_chunks)
+
+            arg_iter = list(
+                zip(
+                    [ibs.dbdir] * num_chunks,
+                    qaids_chunks,
+                    [daids] * num_chunks,
+                    [cfgdict] * num_chunks,
+                    [custom_nid_lookup] * num_chunks,
+                    [verbose] * num_chunks,
+                    [use_cache] * num_chunks,
+                    [invalidate_supercache] * num_chunks,
+                    [ranks_top] * num_chunks,
+                )
+            )
+
+            nprocs = 8
+            logger.info('Creating %d processes' % (nprocs,))
+            executor = futures.ThreadPoolExecutor(nprocs)
+            logger.info('Submitting workers')
+            fs_chunk = []
+            for args in ut.ProgIter(arg_iter, lbl='submit matching threads'):
+                fs = executor.submit(_make_rankings_worker, args)
+                fs_chunk.append(fs)
+
+            results = []
+            try:
+                for fs in ut.ProgIter(fs_chunk, lbl='getting matching result'):
+                    result = fs.result()
+                    results.append(result)
+            except Exception:
+                raise
+            finally:
+                executor.shutdown(wait=True)
+
+            assert len(results) == num_chunks
+            edges = set(ut.flatten(results))
+        else:
+            qreq_ = ibs.new_query_request(
+                qaids,
+                daids,
+                cfgdict=cfgdict,
+                custom_nid_lookup=custom_nid_lookup,
+                verbose=infr.verbose >= 2,
+            )
+
+            # cacher = qreq_.get_big_cacher()
+            # if not cacher.exists():
+            #     pass
+            #     # import sys
+            #     # sys.exit(1)
+
+            cm_list = qreq_.execute(
+                prog_hook=prog_hook,
+                use_cache=use_cache,
+                invalidate_supercache=invalidate_supercache,
+            )
+            infr._set_vsmany_info(qreq_, cm_list)
+
+            edges = set(_cm_breaking_worker(cm_list, review_cfg={'ranks_top': ranks_top}))
 
-        edges = set(infr._cm_breaking(cm_list, review_cfg={'ranks_top': 5}))
         return edges
         # return cm_list
 
@@ -204,38 +363,16 @@ class AnnotInfrMatching(object):
         infr.graph.add_edges_from(edges)
         infr.apply_match_scores()
 
-    def _cm_breaking(infr, cm_list=None, review_cfg={}):
+    def _cm_breaking(infr, cm_list=None, review_cfg={}, scoring='annot'):
         """
         >>> from wbia.algo.graph.core import *  # NOQA
         >>> review_cfg = {}
         """
         if cm_list is None:
             cm_list = infr.cm_list
-        ranks_top = review_cfg.get('ranks_top', None)
-        ranks_bot = review_cfg.get('ranks_bot', None)
-
-        # Construct K-broken graph
-        edges = []
-
-        if ranks_bot is None:
-            ranks_bot = 0
-
-        for count, cm in enumerate(cm_list):
-            score_list = cm.annot_score_list
-            rank_list = ut.argsort(score_list)[::-1]
-            sortx = ut.argsort(rank_list)
-
-            top_sortx = sortx[:ranks_top]
-            bot_sortx = sortx[len(sortx) - ranks_bot :]
-            short_sortx = ut.unique(top_sortx + bot_sortx)
-
-            daid_list = ut.take(cm.daid_list, short_sortx)
-            for daid in daid_list:
-                u, v = (cm.qaid, daid)
-                if v < u:
-                    u, v = v, u
-                edges.append((u, v))
-        return edges
+        return _cm_breaking_worker(
+            cm_list=cm_list, review_cfg=review_cfg, scoring=scoring
+        )
 
     def _cm_training_pairs(
         infr,
@@ -488,7 +625,19 @@ class InfrLearning(object):
         infr.task_thresh = infr.task_thresh_dict[species]
         infr.print('infr.task_thresh: %r' % (infr.task_thresh,))
         infr.print('Loading verifiers for species: %r' % (species,))
-        infr.verifiers = deploy.Deployer().load_published(ibs, species)
+        try:
+            infr.verifiers = deploy.Deployer().load_published(ibs, species)
+            message = 'Loaded verifiers %r' % (infr.verifiers,)
+            infr.print(message)
+        except TypeError as ex:
+            message = 'Error: Failed to load verifiers for %r' % (species,)
+            ut.printex(
+                ex,
+                message,
+                iswarning=True,
+                tb=True,
+            )
+            infr.print(message)
 
     def load_latest_classifiers(infr, dpath):
         from wbia.algo.verif import deploy
@@ -681,7 +830,6 @@ class _RedundancyAugmentation(object):
         for pcc in prog:
             if not infr.is_pos_redundant(pcc, k=k, relax=True, assume_connected=True):
                 for edge in infr.find_pos_augment_edges(pcc, k=k):
-                    print()
                     yield nxu.e_(*edge)
 
     @profile
@@ -740,16 +888,29 @@ class CandidateSearch(_RedundancyAugmentation):
     """ Search for candidate edges """
 
     @profile
-    def find_lnbnn_candidate_edges(infr):
+    def find_lnbnn_candidate_edges(
+        infr,
+        desired_states=[UNREV],
+        can_match_samename=False,
+        can_match_sameimg=False,
+        K=5,
+        Knorm=5,
+        requery=True,
+        prescore_method='csum',
+        score_method='csum',
+        sv_on=True,
+        cfgdict_=None,
+        batch_size=None,
+    ):
         """
 
         Example:
+            >>> # DISABLE_DOCTEST
             >>> # xdoctest: +REQUIRES(--slow)
-            >>> # ENABLE_DOCTEST
             >>> from wbia.algo.graph import demo
             >>> infr = demo.demodata_mtest_infr()
             >>> cand_edges = infr.find_lnbnn_candidate_edges()
-            >>> assert len(cand_edges) > 200
+            >>> assert len(cand_edges) > 200, len(cand_edges)
         """
         # Refresh the name labels
 
@@ -757,30 +918,47 @@ class CandidateSearch(_RedundancyAugmentation):
 
         # do LNBNN query for new edges
         # Use one-vs-many to establish candidate edges to classify
-        infr.exec_matching(
-            name_method='edge',
-            cfgdict={
-                'resize_dim': 'width',
-                'dim_size': 700,
-                'requery': True,
-                'can_match_samename': False,
-                'can_match_sameimg': False,
-                # 'sv_on': False,
-            },
-        )
-        # infr.apply_match_edges(review_cfg={'ranks_top': 5})
+        cfgdict = {
+            'resize_dim': 'width',
+            'dim_size': 700,
+            'requery': requery,
+            'can_match_samename': can_match_samename,
+            'can_match_sameimg': can_match_sameimg,
+            'K': K,
+            'Knorm': Knorm,
+            'sv_on': sv_on,
+            'prescore_method': prescore_method,
+            'score_method': score_method,
+        }
+        if cfgdict_ is not None:
+            cfgdict.update(cfgdict_)
+
+        print('[find_lnbnn_candidate_edges] Using cfgdict = %s' % (ut.repr3(cfgdict),))
+
         ranks_top = infr.params['ranking.ntop']
-        lnbnn_results = set(infr._cm_breaking(review_cfg={'ranks_top': ranks_top}))
+        response = infr.exec_matching(
+            name_method='edge',
+            cfgdict=cfgdict,
+            batch_size=batch_size,
+            ranks_top=ranks_top,
+        )
+
+        if cfgdict_ is None:
+            # infr.apply_match_edges(review_cfg={'ranks_top': 5})
+            lnbnn_results = set(infr._cm_breaking(review_cfg={'ranks_top': ranks_top}))
+        else:
+            assert response is not None
+            lnbnn_results = set(response)
 
         candidate_edges = {
             edge
             for edge, state in zip(lnbnn_results, infr.edge_decision_from(lnbnn_results))
-            if state == UNREV
+            if state in desired_states
         }
 
         infr.print(
-            'ranking alg found {}/{} unreviewed edges'.format(
-                len(candidate_edges), len(lnbnn_results)
+            'ranking alg found {}/{} {} edges'.format(
+                len(candidate_edges), len(lnbnn_results), desired_states
             ),
             1,
         )
@@ -831,6 +1009,7 @@ class CandidateSearch(_RedundancyAugmentation):
 
         if any(need_flags):
             need_edges = ut.compress(edges, need_flags)
+            need_edges = list(set(need_edges))
             infr.print(
                 'There are {} edges without probabilities'.format(len(need_edges)), 1
             )
