@@ -5,7 +5,6 @@ This includes recordings measures used to generate plots in JC's thesis.
 """
 # -*- coding: utf-8 -*-
 import logging
-import six
 import utool as ut
 import ubelt as ub
 import pandas as pd
@@ -26,6 +25,7 @@ class SimulationHelpers(object):
         enable_inference=True,
         classifiers=None,
         match_state_thresh=None,
+        pb_state_thresh=None,
         max_outer_loops=None,
         name=None,
     ):
@@ -55,7 +55,6 @@ class SimulationHelpers(object):
                 INCMP: 1.0,
             }
 
-        pb_state_thresh = None
         if pb_state_thresh is None:
             pb_state_thresh = {
                 'pb': 0.5,
@@ -229,10 +228,10 @@ class SimulationHelpers(object):
             'pred_decision': infr.test_state['pred_decision'],
             'true_decision': infr.test_state['true_decision'],
             'n_neg_redun': infr.neg_redun_metagraph.number_of_edges(),
-            'n_neg_redun1': (
-                infr.neg_metagraph.number_of_edges()
-                - infr.neg_metagraph.number_of_selfloops()
-            ),
+            # 'n_neg_redun1': (
+            #     infr.neg_metagraph.number_of_edges()
+            #     - infr.neg_metagraph.number_of_selfloops()
+            # ),
         }
 
         return metrics
@@ -425,7 +424,7 @@ class SimulationHelpers(object):
 
 class UserOracle(object):
     def __init__(oracle, accuracy, rng):
-        if isinstance(rng, six.string_types):
+        if isinstance(rng, str):
             rng = sum(map(ord, rng))
         rng = ut.ensure_rng(rng, impl='python')
 
