@@ -4,9 +4,7 @@ NEEDS CLEANUP
 """
 import logging
 from os.path import join
-import six
 import utool as ut
-from six.moves import range, zip, map  # NOQA
 from wbia.algo.hots import _pipeline_helpers as plh  # NOQA
 from wbia.algo.hots.neighbor_index import NeighborIndex, get_support_data
 
@@ -77,7 +75,7 @@ class UUIDMapHyrbridCache(object):
     #    with lockfile.LockFile(uuid_map_fpath + '.lock'):
     #        with ut.shelf_open(uuid_map_fpath) as uuid_map:
     #            candidate_uuids = {
-    #                key: val for key, val in six.iteritems(uuid_map)
+    #                key: val for key, val in uuid_map.items()
     #                if len(val) >= min_reindex_thresh
     #            }
     #    return candidate_uuids
@@ -96,7 +94,7 @@ class UUIDMapHyrbridCache(object):
     #        try:
     #            uuid_map = ut.load_cPkl(uuid_map_fpath)
     #            candidate_uuids = {
-    #                key: val for key, val in six.iteritems(uuid_map)
+    #                key: val for key, val in uuid_map.items()
     #                if len(val) >= min_reindex_thresh
     #            }
     #        except IOError:
@@ -124,9 +122,7 @@ class UUIDMapHyrbridCache(object):
         """ uses in memory dictionary instead of disk """
         uuid_map = self.uuid_maps[uuid_map_fpath]
         candidate_uuids = {
-            key: val
-            for key, val in six.iteritems(uuid_map)
-            if len(val) >= min_reindex_thresh
+            key: val for key, val in uuid_map.items() if len(val) >= min_reindex_thresh
         }
         return candidate_uuids
 
@@ -338,14 +334,14 @@ def request_augmented_wbia_nnindexer(
         >>> ZEB_PLAIN = wbia.const.TEST_SPECIES.ZEB_PLAIN
         >>> ibs = wbia.opendb('testdb1')
         >>> use_memcache, max_covers, verbose = True, None, True
-        >>> daid_list = ibs.get_valid_aids(species=ZEB_PLAIN)[0:6]
+        >>> daid_list = sorted(ibs.get_valid_aids(species=ZEB_PLAIN))[0:6]
         >>> qreq_ = ibs.new_query_request(daid_list, daid_list)
         >>> qreq_.qparams.min_reindex_thresh = 1
         >>> min_reindex_thresh = qreq_.qparams.min_reindex_thresh
         >>> # CLEAR CACHE for clean test
         >>> clear_uuid_cache(qreq_)
         >>> # LOAD 3 AIDS INTO CACHE
-        >>> aid_list = ibs.get_valid_aids(species=ZEB_PLAIN)[0:3]
+        >>> aid_list = sorted(ibs.get_valid_aids(species=ZEB_PLAIN))[0:3]
         >>> # Should fallback
         >>> nnindexer = request_augmented_wbia_nnindexer(qreq_, aid_list)
         >>> # assert the fallback
@@ -630,7 +626,7 @@ def group_daids_by_cached_nnindexer(
         >>> # STEP 0: CLEAR THE CACHE
         >>> clear_uuid_cache(qreq_)
         >>> # STEP 1: ASSERT EMPTY INDEX
-        >>> daid_list = ibs.get_valid_aids(species=ZEB_PLAIN)[0:3]
+        >>> daid_list = sorted(ibs.get_valid_aids(species=ZEB_PLAIN))[0:3]
         >>> uncovered_aids, covered_aids_list = group_daids_by_cached_nnindexer(
         ...     qreq_, daid_list, min_reindex_thresh, max_covers)
         >>> result1 = uncovered_aids, covered_aids_list
