@@ -190,7 +190,7 @@ def new_wbia_query_request(
         if verbose > 2:
             logger.info('[qreq] piperoot HACK')
         requestclass = ibs.depc_annot.requestclass_dict[piperoot]
-        assert custom_nid_lookup is None, 'unsupported'
+        # assert custom_nid_lookup is None, 'unsupported'
         qreq_ = request = requestclass.new(  # NOQA
             ibs.depc_annot, qaid_list, daid_list, cfgdict, tablename=piperoot
         )
@@ -211,6 +211,7 @@ def new_wbia_query_request(
         else:
             unique_species_ = unique_species
         # </HACK>
+
         if query_cfg is None:
             cfg = ibs.cfg.query_cfg
         else:
@@ -218,7 +219,7 @@ def new_wbia_query_request(
 
         qparams = query_params.QueryParams(cfg, cfgdict)
         data_config2_ = qparams
-        #
+
         # <HACK>
         # MAKE A SECOND CONFIG FOR QUERIES AND DATABASE VECTORS ONLY
         # allow query and database annotations to have different feature configs
@@ -229,6 +230,7 @@ def new_wbia_query_request(
         else:
             query_config2_ = qparams
         # </HACK>
+
         _indexer_request_params = dict(use_memcache=use_memcache)
         qreq_ = QueryRequest.new_query_request(
             qaid_list,
@@ -582,7 +584,7 @@ class QueryRequest(ut.NiceRepr):
             >>> # ENABLE_DOCTEST
             >>> from wbia.algo.hots.query_request import *  # NOQA
             >>> import wbia
-            >>> from six.moves import cPickle as pickle
+            >>> import pickle
             >>> qreq_ = wbia.testdata_qreq_()
             >>> qreq_dump = pickle.dumps(qreq_)
             >>> qreq2_ = pickle.loads(qreq_dump)
@@ -1278,7 +1280,12 @@ class QueryRequest(ut.NiceRepr):
             yield fpath
 
     def execute(
-        qreq_, qaids=None, prog_hook=None, use_cache=None, invalidate_supercache=None
+        qreq_,
+        qaids=None,
+        prog_hook=None,
+        use_cache=None,
+        use_supercache=None,
+        invalidate_supercache=None,
     ):
         r"""
         Runs the hotspotter pipeline and returns chip match objects.
@@ -1318,7 +1325,7 @@ class QueryRequest(ut.NiceRepr):
                 use_bigcache=use_cache,
                 verbose=True,
                 save_qcache=use_cache,
-                use_supercache=False,
+                use_supercache=use_supercache,
                 invalidate_supercache=invalidate_supercache,
             )
         return cm_list
