@@ -9,7 +9,6 @@ import pandas as pd
 from sklearn.utils.validation import check_array
 
 # from sklearn.utils import check_random_state
-from six.moves import zip
 
 # from sklearn.model_selection._split import (_BaseKFold, KFold)
 from sklearn.model_selection._split import _BaseKFold
@@ -512,11 +511,9 @@ def classification_report2(
     # and BM * MK MCC?
 
     def matthews_corrcoef(y_true, y_pred, sample_weight=None):
-        from sklearn.metrics.classification import (
-            _check_targets,
-            LabelEncoder,
-            confusion_matrix,
-        )
+        from sklearn.preprocessing import LabelEncoder
+        from sklearn.metrics import confusion_matrix
+        from sklearn.metrics._classification import _check_targets
 
         y_type, y_true, y_pred = _check_targets(y_true, y_pred)
         if y_type not in {'binary', 'multiclass'}:
@@ -585,9 +582,7 @@ def predict_from_probs(probs, method='argmax', target_names=None, **kwargs):
         >>> pred3 = predict_from_probs(probs, threshes.values, force=True,
         >>>                            target_names=probs.columns)
     """
-    import six
-
-    if isinstance(method, six.string_types) and method == 'argmax':
+    if isinstance(method, str) and method == 'argmax':
         if isinstance(probs, pd.DataFrame):
             pred_enc = pd.Series(probs.values.argmax(axis=1), index=probs.index)
         else:
