@@ -3,7 +3,6 @@ import logging
 import utool as ut
 import ubelt as ub  # NOQA
 import numpy as np
-from six.moves import zip, map, filter, range  # NOQA
 from functools import partial  # NOQA
 from wbia.control import controller_inject
 
@@ -45,14 +44,15 @@ def get_annotmatch_rowids_from_aid1(ibs, aid1_list, eager=True, nInput=None):
     params_iter = zip(aid1_list)
     if True:
         # HACK IN INDEX
-        ibs.db.connection.execute(
-            """
-            CREATE INDEX IF NOT EXISTS aid1_to_am ON {ANNOTMATCH_TABLE} ({annot_rowid1});
-            """.format(
-                ANNOTMATCH_TABLE=ibs.const.ANNOTMATCH_TABLE,
-                annot_rowid1=manual_annotmatch_funcs.ANNOT_ROWID1,
+        with ibs.db.connect() as conn:
+            conn.execute(
+                """
+                CREATE INDEX IF NOT EXISTS aid1_to_am ON {ANNOTMATCH_TABLE} ({annot_rowid1});
+                """.format(
+                    ANNOTMATCH_TABLE=ibs.const.ANNOTMATCH_TABLE,
+                    annot_rowid1=manual_annotmatch_funcs.ANNOT_ROWID1,
+                )
             )
-        ).fetchall()
     where_colnames = [manual_annotmatch_funcs.ANNOT_ROWID1]
     annotmatch_rowid_list = ibs.db.get_where_eq(
         ibs.const.ANNOTMATCH_TABLE,
@@ -82,14 +82,15 @@ def get_annotmatch_rowids_from_aid2(
         nInput = len(aid2_list)
     if True:
         # HACK IN INDEX
-        ibs.db.connection.execute(
-            """
-            CREATE INDEX IF NOT EXISTS aid2_to_am ON {ANNOTMATCH_TABLE} ({annot_rowid2});
-            """.format(
-                ANNOTMATCH_TABLE=ibs.const.ANNOTMATCH_TABLE,
-                annot_rowid2=manual_annotmatch_funcs.ANNOT_ROWID2,
+        with ibs.db.connect() as conn:
+            conn.execute(
+                """
+                CREATE INDEX IF NOT EXISTS aid2_to_am ON {ANNOTMATCH_TABLE} ({annot_rowid2});
+                """.format(
+                    ANNOTMATCH_TABLE=ibs.const.ANNOTMATCH_TABLE,
+                    annot_rowid2=manual_annotmatch_funcs.ANNOT_ROWID2,
+                )
             )
-        ).fetchall()
     colnames = (manual_annotmatch_funcs.ANNOTMATCH_ROWID,)
     # FIXME: col_rowid is not correct
     params_iter = zip(aid2_list)
