@@ -5,12 +5,12 @@ string correctly every time you use it. (Also it makes it much easier if a
 string name changes)
 """
 import logging
-import six
 import numpy as np
 import math
 import utool as ut
 from collections import OrderedDict
 from os.path import join
+import six
 
 (print, rrr, profile) = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
@@ -270,6 +270,7 @@ ANNOTMATCH_TABLE = 'annotmatch'
 SPECIES_TABLE = 'species'
 RESIDUAL_TABLE = 'residuals'
 VERSIONS_TABLE = 'versions'
+WEIGHT_TABLE = 'weights'
 #
 PARTY_CONTRIB_RELATION_TABLE = 'party_contrib_relation'
 PARTY_TABLE = 'party'
@@ -354,6 +355,7 @@ class ZIPPED_URLS(object):  # NOQA
     ORIENTATION = (
         'https://wildbookiarepository.azureedge.net/databases/testdb_orientation.zip'
     )
+    ASSIGNER = 'https://wildbookiarepository.azureedge.net/databases/testdb_assigner.zip'
     K7_EXAMPLE = 'https://wildbookiarepository.azureedge.net/databases/testdb_kaggle7.zip'
 
 
@@ -389,12 +391,17 @@ SPECIES_WITH_DETECTORS = (
     'dolphin_spotted+fin_dorsal',
     'giraffe_masai',
     'giraffe_reticulated',
+    'grouper_nassau',
+    'hyaena',
     'jaguar',
     'leopard',
     'lynx',
     'manta_ray',
     'manta_ray_giant',
     'right_whale_head',
+    'salanader_fire',
+    'salanader_fire_larvae',
+    'salanader_fire_adult',
     'seadragon_leafy',
     'seadragon_leafy+head',
     'seadragon_weedy',
@@ -431,31 +438,46 @@ SPECIES_WITH_DETECTORS = (
     'whale_humpback+fin_dorsal',
     'whale_humpback+fin_dorsal_back',
     'whale_humpback+fin_dorsal_front',
-    'whale_orca+fin_dorsal',
     'whale_pilot+fin_dorsal',
+    'whale_beluga',
+    'beluga_whale',
+    'mediterranean_monk_seal',
+    'grey_seal',
+    'grey_seal_unknown',
+    'grey_seal_male',
+    'grey_seal_femaleyoung',
+    'grey_seal_pup',
+    'harbour_seal',
+    'hawaiian_monk_seal',
     # Latin (Flukebook)
     'chelonioidea',
     'chelonioidea+head',
     'chelonia_mydas',
     'chelonia_mydas+head',
+    'delphinapterus_leucas',
     'eretmochelys_imbricata',
     'eretmochelys_imbricata+head',
-    'lepidochelys_olivacea',
-    'lepidochelys_olivacea+head',
     'eubalaena_australis',
     'eubalaena_glacialis',
+    'epinephelus_striatus',
     'equus_quagga',
     'equus_grevyi',
     'equus_zebra',
     'giraffa_tippelskirchi',
     'giraffa_camelopardalis_reticulata',
+    'hyaena_hyaena',
+    'lepidochelys_olivacea',
+    'lepidochelys_olivacea+head',
+    'lynx_pardinus',
     'mobula_birostris',
     'mobula_alfredi',
-    'lynx_pardinus',
     'phycodurus_eques',
     'phycodurus_eques+head',
     'phyllopteryx_taeniolatus',
     'phyllopteryx_taeniolatus+head',
+    'salamandra_salamandra',
+    'salamandra_salamandra_larvae',
+    'salamandra_salamandra_adult',
     'megaptera_novaeangliae',
     'physeter_macrocephalus',
     'physeter_macrocephalus+fin_dorsal',
@@ -470,6 +492,10 @@ SPECIES_WITH_DETECTORS = (
     'panthera_onca',
     'acinonyx_jubatus',
     'lycaon_pictus',
+    'monachus_monachus',
+    'phoca_vitulina',
+    'halichoerus_grypus',
+    'monachus_schauinslandi',
 )
 
 
@@ -514,7 +540,8 @@ SPECIES_MAPPING = {
     'goat_generic': (None, 'goat'),
     'grouper_nassau': ('NG', 'Nassau Grouper'),
     'hippopotamus': ('HIPPO', 'Hippopotamus'),
-    'hyena': ('HYENA', 'Hyena'),
+    'hyena': (None, 'hyaena'),
+    'hyaena': ('HYAENA', 'Hyaena'),
     'ignore': ('IGNORE', 'IGNORE'),
     'indistinct': ('INDISTINCT', 'INDISTINCT'),
     'jaguar': ('JAG', 'Jaguar'),
@@ -573,6 +600,7 @@ SPECIES_MAPPING = {
     'wild_dog+tail_standard': ('WD+STD', 'Wild Dog Tail Standard'),
     'wild_dog': ('WD', 'Wild Dog'),
     'whale_fluke': ('WF', 'Whale Fluke'),
+    'whale_beluga': ('BW', 'Beluga Whale'),
     'whale_humpback': ('HW', 'Humpback Whale'),
     'whale_shark': ('WS', 'Whale Shark'),
     'zebra_grevys': ('GZ', "Zebra (Grevy's)"),
@@ -711,6 +739,7 @@ class META_DECISION(object):  # NOQA
 
 @six.add_metaclass(_ConstHelper)
 class CONFIDENCE(object):
+
     UNKNOWN = None
     GUESSING = 1
     NOT_SURE = 2
@@ -745,6 +774,7 @@ class CONFIDENCE(object):
 
 @six.add_metaclass(_ConstHelper)
 class QUAL(object):
+
     EXCELLENT = 5
     GOOD = 4
     OK = 3
