@@ -10,7 +10,6 @@ python -c "import wbia"
 """
 import logging
 import utool as ut
-import six
 import sys
 from wbia import dtool
 from datetime import timedelta
@@ -22,7 +21,6 @@ from os.path import abspath, join, dirname
 # import simplejson as json
 # import json
 # import pickle
-# from six.moves import cPickle as pickle
 import traceback
 from hashlib import sha1
 import os
@@ -181,12 +179,9 @@ try:
     if GLOBAL_APP_ENABLED:
         get_flask_app()
 except AttributeError:
-    if six.PY3:
-        logger.info('Warning flask is broken in python-3.4.0')
-        GLOBAL_APP_ENABLED = False
-        HAS_FLASK = False
-    else:
-        raise
+    logger.info('Warning flask is broken in python-3.4.0')
+    GLOBAL_APP_ENABLED = False
+    HAS_FLASK = False
 
 
 class WebException(ut.NiceRepr, Exception):
@@ -418,7 +413,7 @@ def translate_wbia_webreturn(
         }
     response = ut.to_json(template)
 
-    if jQuery_callback is not None and isinstance(jQuery_callback, six.string_types):
+    if jQuery_callback is not None and isinstance(jQuery_callback, str):
         logger.info('[web] Including jQuery callback function: %r' % (jQuery_callback,))
         response = '%s(%s)' % (jQuery_callback, response)
     return response
@@ -489,35 +484,20 @@ def translate_wbia_webcall(func, *args, **kwargs):
     Returns:
         tuple: (output, True, 200, None, jQuery_callback)
 
-    CommandLine:
-        python -m wbia.control.controller_inject --exec-translate_wbia_webcall
-        python -m wbia.control.controller_inject --exec-translate_wbia_webcall --domain http://52.33.105.88
-
     Example:
         >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.control.controller_inject import *  # NOQA
         >>> import wbia
-        >>> import time
-        >>> import wbia.web
-        >>> with wbia.opendb_bg_web('testdb1', start_job_queue=False, managed=True) as web_ibs:
-        ...     aids = web_ibs.send_wbia_request('/api/annot/', 'get')
-        ...     uuid_list = web_ibs.send_wbia_request('/api/annot/uuids/', aid_list=aids, json=False)
-        ...     failrsp = web_ibs.send_wbia_request('/api/annot/uuids/', json=False)
-        ...     failrsp2 = web_ibs.send_wbia_request('/api/query/chips/simple_dict//', 'get', qaid_list=[0], daid_list=[0], json=False)
-        ...     log_text = web_ibs.send_wbia_request('/api/query/chips/simple_dict/', 'get', qaid_list=[0], daid_list=[0], json=False)
-        >>> time.sleep(.1)
-        >>> print('\n---\nuuid_list = %r' % (uuid_list,))
-        >>> print('\n---\nfailrsp =\n%s' % (failrsp,))
-        >>> print('\n---\nfailrsp2 =\n%s' % (failrsp2,))
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     aids = client.get('/api/annot/').json
+        ...     failrsp = client.post('/api/annot/uuids/')
+        ...     failrsp2 = client.get('/api/query/chips/simple_dict//', data={'qaid_list': [0], 'daid_list': [0]})
+        ...     log_text = client.get('/api/query/chips/simple_dict/', data={'qaid_list': [0], 'daid_list': [0]})
+        >>> print('\n---\nfailrsp =\n%s' % (failrsp.data,))
+        >>> print('\n---\nfailrsp2 =\n%s' % (failrsp2.data,))
         >>> print('Finished test')
+        Finished test
 
-    Ignore:
-        app = get_flask_app()
-        with app.app_context():
-            #ibs = wbia.opendb('testdb1')
-            func = ibs.get_annot_uuids
-            args = tuple()
-            kwargs = dict()
     """
     assert len(args) == 0, 'There should not be any args=%r' % (args,)
 
@@ -590,7 +570,7 @@ def translate_wbia_webcall(func, *args, **kwargs):
         output = func(**kwargs)
     except TypeError:
         try:
-            output = func(ibs=ibs, **kwargs)
+            output = func(ibs, **kwargs)
         except WebException:
             raise
         except Exception as ex2:  # NOQA
@@ -690,9 +670,8 @@ def get_signature(key, message):
     def decode(x):
         return x.decode('utf-8')
 
-    if six.PY3:
-        key = encode(key)
-        message = encode(message)
+    key = encode(key)
+    message = encode(message)
 
     signature = hmac.new(key, message, sha1)
     signature = signature.digest()
@@ -1098,7 +1077,7 @@ def get_user(username=None, name=None, organization=None):
             session[USER_KEY] = None
         else:
             # Authenticate
-            assert isinstance(username, six.string_types), 'user must be a string'
+            assert isinstance(username, str), 'user must be a string'
             username = username.lower()
             session[USER_KEY] = {
                 'username': username,
