@@ -27,7 +27,7 @@ import numpy as np
 import utool as ut
 import vtool as vt
 from wbia.web import routes_ajax
-import six
+from wbia.utils import call_houston
 
 print, rrr, profile = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
@@ -112,7 +112,13 @@ def _get_all_image_rowids(ibs):
 @accessor_decors.ider
 @register_api('/api/image/', methods=['GET'])
 def get_valid_gids(
-    ibs, imgsetid=None, require_unixtime=False, require_gps=None, reviewed=None, **kwargs
+    ibs,
+    imgsetid=None,
+    imgsetid_list=(),
+    require_unixtime=False,
+    require_gps=None,
+    reviewed=None,
+    **kwargs,
 ):
     r"""
     Args:
@@ -147,8 +153,10 @@ def get_valid_gids(
         >>> print(result)
         [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13]
     """
-    if imgsetid is None:
+    if imgsetid is None and not imgsetid_list:
         gid_list = ibs._get_all_gids()
+    elif imgsetid_list:
+        gid_list = ibs.get_imageset_gids(imgsetid_list)
     else:
         assert not ut.isiterable(imgsetid)
         gid_list = ibs.get_imageset_gids(imgsetid)
@@ -286,7 +294,7 @@ def _compute_image_uuids(ibs, gpath_list, sanitize=True, ensure=True, **kwargs):
 @register_ibs_method
 @register_api('/api/image/uuid/', methods=['POST'])
 def compute_image_uuids(ibs, gpath_list, **kwargs):
-    params_list = _compute_image_uuids(ibs, gpath_list, **kwargs)
+    params_list = ibs._compute_image_uuids(gpath_list, **kwargs)
 
     uuid_colx = IMAGE_COLNAMES.index('image_uuid')
     uuid_list = [
@@ -310,7 +318,7 @@ def add_images(
     ensure_unique=False,
     ensure_loadable=True,
     ensure_exif=True,
-    **kwargs
+    **kwargs,
 ):
     r"""
     Adds a list of image paths to the database.
@@ -397,15 +405,11 @@ def add_images(
         )
     # </DEBUG>
 
-    # Execute SQL Add
-    from distutils.version import LooseVersion
-
-    if LooseVersion(ibs.db.get_db_version()) >= LooseVersion('1.3.4'):
-        colnames = IMAGE_COLNAMES + ('image_original_path', 'image_location_code')
-        params_list = [
-            tuple(params) + (gpath, location_for_names) if params is not None else None
-            for params, gpath in zip(params_list, gpath_list)
-        ]
+    colnames = IMAGE_COLNAMES + ('image_original_path', 'image_location_code')
+    params_list = [
+        tuple(params) + (gpath, location_for_names) if params is not None else None
+        for params, gpath in zip(params_list, gpath_list)
+    ]
 
     all_gid_list = ibs.db.add_cleanly(
         const.IMAGE_TABLE, colnames, params_list, ibs.get_image_gids_from_uuid
@@ -508,6 +512,7 @@ def localize_images(ibs, gid_list_=None):
         >>> # ENABLE_DOCTEST
         >>> from wbia.control.manual_image_funcs import *  # NOQA
         >>> import wbia
+        >>> import os
         >>> # build test data
         >>> ibs = wbia.opendb('testdb1')
         >>> gpath_list  = [ut.unixpath(ut.grab_test_imgpath('carl.jpg'))]
@@ -523,31 +528,23 @@ def localize_images(ibs, gid_list_=None):
         >>> result = rel_gpath3
         >>> print(result)
         >>> # Clean things up
+        >>> paths = ibs.get_image_paths(gid_list_)
         >>> ibs.delete_images(gid_list_)
-        ...
-        testdb1/_ibsdb/images/f498fa6f-6b24-b4fa-7932-2612144fedd5.jpg
-        ...
+        >>> for path in paths:
+        >>>     assert not os.path.exists(path)
 
     Ignore:
         ibs.vd()
 
     """
     # from os.path import isabs
-    import six
     import requests
 
-    if six.PY2:
-        import urllib
-        import urlparse
+    import urllib
 
-        urlsplit = urlparse.urlsplit
-        urlquote = urllib.quote
-    else:
-        import urllib
-
-        urlsplit = urllib.parse.urlsplit
-        urlquote = urllib.parse.quote
-        urlunquote = urllib.parse.unquote
+    urlsplit = urllib.parse.urlsplit
+    urlquote = urllib.parse.quote
+    urlunquote = urllib.parse.unquote
 
     if gid_list_ is None:
         logger.info('WARNING: you are localizing all gids')
@@ -560,7 +557,8 @@ def localize_images(ibs, gid_list_=None):
 
     url_protos = ['https://', 'http://']
     s3_proto = ['s3://']
-    valid_protos = s3_proto + url_protos
+    houston_proto = ['houston+']
+    valid_protos = s3_proto + url_protos + houston_proto
 
     def isproto(uri, valid_protos):
         return any(uri.startswith(proto) for proto in valid_protos)
@@ -592,17 +590,17 @@ def localize_images(ibs, gid_list_=None):
                 uri_ = uri_._replace(path=uri_path)
                 uri_ = uri_.geturl()
                 try:
-                    # six.moves.urllib.request.urlretrieve(uri_, filename=temp_filepath)
                     response = requests.get(uri_, stream=True, allow_redirects=True)
                     assert (
                         response.status_code == 200
                     ), '200 code not received on download'
                 except Exception:
-                    scheme = urlsplit(uri_, allow_fragments=False).scheme
-                    uri_ = uri_.strip('%s://' % (scheme,))
-                    uri_path = urlquote(uri_.encode('utf8'))
-                    uri_ = '%s://%s' % (scheme, uri_path)
-                    # six.moves.urllib.request.urlretrieve(uri_, filename=temp_filepath)
+                    parts = urlsplit(uri_, allow_fragments=False)
+                    uri_ = uri_[len('%s://' % (parts.scheme,)) :]
+                    hostname = urlquote(parts.hostname.encode('utf8'))
+                    if parts.port:
+                        hostname = f'{hostname}:{parts.port}'
+                    uri_ = '%s://%s%s' % (parts.scheme, hostname, parts.path)
                     response = requests.get(uri_, stream=True, allow_redirects=True)
                     assert (
                         response.status_code == 200
@@ -611,6 +609,14 @@ def localize_images(ibs, gid_list_=None):
                 with open(loc_gpath, 'wb') as temp_file_:
                     for chunk in response.iter_content(1024):
                         temp_file_.write(chunk)
+            elif isproto(uri, houston_proto):
+                response = call_houston(uri)
+                assert (
+                    response.status_code == 200
+                ), f'200 code not received on download: {uri}'
+                with open(loc_gpath, 'wb') as temp_file_:
+                    for chunk in response.iter_content(1024):
+                        temp_file_.write(chunk)
             else:
                 raise ValueError('Sanity check failed')
         else:
@@ -1048,8 +1054,7 @@ def _set_image_sizes(ibs, gid_list, width_list, height_list):
 
 @register_ibs_method
 @accessor_decors.setter
-@register_api('/api/image/orientation/', methods=['PUT'])
-def _set_image_orientation(ibs, gid_list, orientation_list):
+def _set_image_orientation(ibs, gid_list, orientation_list, clean_derivatives=True):
     r"""
     RESTful:
         Method: PUT
@@ -1059,8 +1064,68 @@ def _set_image_orientation(ibs, gid_list, orientation_list):
     val_list = ((orientation,) for orientation in orientation_list)
     id_iter = ((gid,) for gid in gid_list)
     ibs.db.set(const.IMAGE_TABLE, colnames, val_list, id_iter)
-    ibs.depc_image.notify_root_changed(gid_list, 'image_orientation')
-    ibs.delete_image_thumbs(gid_list)
+
+    if clean_derivatives:
+        # Delete image's thumbs
+        ibs.depc_image.notify_root_changed(gid_list, 'image_orientation')
+        ibs.delete_image_thumbs(gid_list)
+
+        # Delete annotation's thumbs
+        aid_list = ut.flatten(ibs.get_image_aids(gid_list))
+        ibs.delete_annot_chips(aid_list)
+        ibs.delete_annot_imgthumbs(aid_list)
+        gid_list = list(set(ibs.get_annot_gids(aid_list)))
+        config2_ = {'thumbsize': 221}
+        ibs.delete_image_thumbs(gid_list, quiet=True, **config2_)
+
+
+@register_ibs_method
+@accessor_decors.setter
+@register_api('/api/image/orientation/', methods=['PUT'])
+def set_image_orientation(ibs, gid_list, orientation_list):
+    r"""
+    RESTful:
+        Method: PUT
+        URL:    /api/image/orientation/
+    """
+    from vtool.exif import (
+        ORIENTATION_DICT_INVERSE,
+        ORIENTATION_UNDEFINED,
+        ORIENTATION_000,
+    )
+
+    undefined = ORIENTATION_DICT_INVERSE[ORIENTATION_UNDEFINED]
+    normal = ORIENTATION_DICT_INVERSE[ORIENTATION_000]
+    existing_orientation_list = ibs.get_image_orientation(gid_list)
+    existing_orientation_list = [
+        normal if val == undefined else val for val in existing_orientation_list
+    ]
+
+    path_funcs = {
+        (1, 3): ibs.update_image_rotate_180,
+        (1, 6): ibs.update_image_rotate_right_90,
+        (1, 8): ibs.update_image_rotate_left_90,
+        (3, 1): ibs.update_image_rotate_180,
+        (3, 6): ibs.update_image_rotate_left_90,
+        (3, 8): ibs.update_image_rotate_right_90,
+        (6, 1): ibs.update_image_rotate_left_90,
+        (6, 3): ibs.update_image_rotate_right_90,
+        (6, 8): ibs.update_image_rotate_180,
+        (8, 1): ibs.update_image_rotate_right_90,
+        (8, 3): ibs.update_image_rotate_left_90,
+        (8, 6): ibs.update_image_rotate_180,
+    }
+    for gid, existing_orientation, orientation in zip(
+        gid_list, existing_orientation_list, orientation_list
+    ):
+        if orientation == undefined:
+            orientation = normal
+        if existing_orientation == orientation:
+            continue
+        path = (existing_orientation, orientation)
+        path_func = path_funcs.get(path, None)
+        assert path_func is not None, 'Could not find path %r' % (path,)
+        path_func([gid])
 
 
 def update_image_rotate_90(ibs, gid_list, direction):
@@ -1089,7 +1154,7 @@ def update_image_rotate_90(ibs, gid_list, direction):
             bbox_list_.append(bbox_)
         ibs.set_annot_bboxes(aid_list, bbox_list_)
 
-    if isinstance(direction, six.string_types):
+    if isinstance(direction, str):
         direction = direction.lower()
 
     if direction in ['left', 'l', -1]:
@@ -1180,7 +1245,7 @@ def update_image_rotate_180(ibs, gid_list):
 
 @register_ibs_method
 @accessor_decors.getter_1to1
-def get_images(ibs, gid_list, force_orient=True, **kwargs):
+def get_images(ibs, gid_list, ignore_orient=False, **kwargs):
     r"""
     Returns:
         list_ (list): a list of images in numpy matrix form by gid
@@ -1210,7 +1275,7 @@ def get_images(ibs, gid_list, force_orient=True, **kwargs):
         (715, 1047, 3)
     """
     orient_list = ibs.get_image_orientation(gid_list)
-    orient_list = [orient if force_orient else False for orient in orient_list]
+    orient_list = [False if ignore_orient else orient for orient in orient_list]
     gpath_list = ibs.get_image_paths(gid_list)
     zipped = zip(gpath_list, orient_list)
     image_list = [vt.imread(gpath, orient=orient) for gpath, orient in zipped]
@@ -1219,9 +1284,9 @@ def get_images(ibs, gid_list, force_orient=True, **kwargs):
 
 @register_ibs_method
 @accessor_decors.getter_1to1
-def get_image_imgdata(ibs, gid_list, force_orient=False, **kwargs):
+def get_image_imgdata(ibs, gid_list, ignore_orient=False, **kwargs):
     """ alias for get_images with standardized name """
-    return get_images(ibs, gid_list, force_orient=force_orient, **kwargs)
+    return get_images(ibs, gid_list, ignore_orient=ignore_orient, **kwargs)
 
 
 @register_ibs_method
@@ -1604,17 +1669,17 @@ def get_image_hash(ibs, gid_list=None, algo='md5'):
         >>> image_path = ibs.get_image_paths(gid_list)
         >>> print('Hashing: %r' % (image_path, ))
         >>> hash_list = ibs.get_image_hash(gid_list, algo='md5')
-        >>> assert hash_list == ['fb5da58f9f49676dbb513a775be6b942']
+        >>> assert hash_list[0] in ['56498e54b5ebbcbbcff60c91a135e8a3', 'ab31dc5e1355247a0ea5ec940802a468'], 'Found %r' % (hash_list, )
         >>> hash_list = ibs.get_image_hash(gid_list, algo='sha1')
-        >>> assert hash_list == ['f716b40e17cb2d7850def23f7d720ca28b147b62'], hash_list
+        >>> assert hash_list[0] in ['277e8dac1e5929c097f3fcbca2c77d92e1401d5f', '66ec193a1619b3b6216d1784b4833b6194b13384'], 'Found %r' % (hash_list, )
         >>> hash_list = ibs.get_image_hash(gid_list, algo='sha256')
-        >>> assert hash_list == ['24c6cb43f5301222a6a7f19ac1e0c578e16aa5c844561a8b2c16b2a478921f08'], hash_list
+        >>> assert hash_list[0] in ['ca03a0d7427c3d2f02e62e157e8d8ea5b7284be67ca67fc391a5747368d3ab0e', 'fd09d22ec18c32d9db2cd026a9511ab228aadf0e5f7271760413448ddd16d483'], 'Found %r' % (hash_list, )
         >>> hash_list = ibs.get_image_hash(gid_list, algo='sha512')
-        >>> assert hash_list == ['bbde99d7e376339905bac68a8375d00208f68344a9ca41dd02a22d6dc426dfe6bace43a41dfe49e474a5fe335f09001c0fdd3350d5b8978f5fc5cc615d3cbbed']
+        >>> assert hash_list[0] in ['7b43dbc709a8cf903170b414f48a0bb7b569b703d9393c20a2cff95c42fd252ed2098bc56cba8eed393bcdf3388e55eee917908c6b0d1b4bc78cf76b1e918d99', '81d1d8ee4c8640b9aad26e4cc03536ed30a43b69e166748ec940a8f00e4776be93f4ac6367a06d92b772a9a60dc104c6f999e7197c2584fdc4cffcac2da71506'], 'Found %r' % (hash_list, )
     """
     import hashlib
 
-    assert isinstance(algo, six.string_types)
+    assert isinstance(algo, str)
     algo = algo.lower()
     assert algo in ['md5', 'sha1', 'sha256', 'sha512']
 
@@ -2172,13 +2237,14 @@ def get_image_imgsetids(ibs, gid_list):
     if NEW_INDEX_HACK:
         # FIXME: This index should when the database is defined.
         # Ensure that an index exists on the image column of the annotation table
-        ibs.db.connection.execute(
-            """
-            CREATE INDEX IF NOT EXISTS gs_to_gids ON {GSG_RELATION_TABLE} ({IMAGE_ROWID});
-            """.format(
-                GSG_RELATION_TABLE=const.GSG_RELATION_TABLE, IMAGE_ROWID=IMAGE_ROWID
+        with ibs.db.connect() as conn:
+            conn.execute(
+                """
+                CREATE INDEX IF NOT EXISTS gs_to_gids ON {GSG_RELATION_TABLE} ({IMAGE_ROWID});
+                """.format(
+                    GSG_RELATION_TABLE=const.GSG_RELATION_TABLE, IMAGE_ROWID=IMAGE_ROWID
+                )
             )
-        ).fetchall()
     colnames = ('imageset_rowid',)
     imgsetids_list = ibs.db.get(
         const.GSG_RELATION_TABLE,
@@ -2222,7 +2288,7 @@ def get_image_imagesettext(ibs, gid_list):
 @accessor_decors.getter_1toM
 @accessor_decors.cache_getter(const.IMAGE_TABLE, ANNOT_ROWIDS)
 @register_api('/api/image/annot/rowid/', methods=['GET'])
-def get_image_aids(ibs, gid_list, is_staged=False, __check_staged__=True):
+def get_image_aids(ibs, gid_list, is_staged=False):
     r"""
     Returns:
         list_ (list): a list of aids for each image by gid
@@ -2276,14 +2342,15 @@ def get_image_aids(ibs, gid_list, is_staged=False, __check_staged__=True):
         # FIXME: This index should when the database is defined.
         # Ensure that an index exists on the image column of the annotation table
 
-        ibs.db.connection.execute(
-            """
-            CREATE INDEX IF NOT EXISTS gid_to_aids ON annotations (image_rowid);
-            """
-        ).fetchall()
+        with ibs.db.connect() as conn:
+            conn.execute(
+                """
+                CREATE INDEX IF NOT EXISTS gid_to_aids ON annotations (image_rowid);
+                """
+            )
 
         # The index maxes the following query very efficient
-        if __check_staged__:
+        if is_staged is not None:
             params_iter = ((gid, is_staged) for gid in gid_list)
             where_colnames = (
                 IMAGE_ROWID,
@@ -2320,7 +2387,8 @@ def get_image_aids(ibs, gid_list, is_staged=False, __check_staged__=True):
         """.format(
             input_str=input_str, ANNOTATION_TABLE=const.ANNOTATION_TABLE
         )
-        pair_list = ibs.db.connection.execute(opstr).fetchall()
+        with ibs.db.connect() as conn:
+            pair_list = conn.execute(opstr).fetchall()
         aidscol = np.array(ut.get_list_column(pair_list, 0))
         gidscol = np.array(ut.get_list_column(pair_list, 1))
         unique_gids, groupx = vt.group_indices(gidscol)
