@@ -7,7 +7,6 @@ Autogen:
     sh Tgen.sh --key part --invert --Tcfg with_getters=True with_setters=True --modfname manual_part_funcs --funcname-filter=is_ --diff  # NOQA
 """
 import logging
-import six
 import uuid
 import numpy as np
 from wbia import constants as const
@@ -29,7 +28,7 @@ register_api = controller_inject.get_wbia_flask_api(__name__)
 PART_NOTE = 'part_note'
 PART_NUM_VERTS = 'part_num_verts'
 PART_ROWID = 'part_rowid'
-# PART_TAG_TEXT           = 'part_tag_text'
+PART_TAG_TEXT = 'part_tag_text'
 PART_THETA = 'part_theta'
 PART_VERTS = 'part_verts'
 PART_UUID = 'part_uuid'
@@ -107,6 +106,8 @@ def filter_part_set(
     viewpoint='no-filter',
     minqual=None,
 ):
+    if not part_rowid_list:  # no need to filter if empty
+        return part_rowid_list
     # -- valid part_rowid filtering --
 
     # filter by is_staged
@@ -230,7 +231,7 @@ def add_parts(
         type_list = [const.UNKNOWN] * len(aid_list)
 
     nVert_list = [len(verts) for verts in vert_list]
-    vertstr_list = [six.text_type(verts) for verts in vert_list]
+    vertstr_list = [str(verts) for verts in vert_list]
     xtl_list, ytl_list, width_list, height_list = list(zip(*bbox_list))
     assert len(nVert_list) == len(vertstr_list)
 
@@ -948,8 +949,9 @@ def _update_part_rotate_fix_bbox(bbox):
 
 def update_part_rotate_90(ibs, part_rowid_list, direction):
     from wbia.constants import PI, TAU
+    import vtool as vt
 
-    if isinstance(direction, six.string_types):
+    if isinstance(direction, str):
         direction = direction.lower()
 
     if direction in ['left', 'l', -1]:
@@ -967,6 +969,49 @@ def update_part_rotate_90(ibs, part_rowid_list, direction):
     bbox_list = [_update_part_rotate_fix_bbox(bbox) for bbox in bbox_list]
     ibs.set_part_bboxes(part_rowid_list, bbox_list)
 
+    # Update part contours
+    part_contours = ibs.get_part_contour(part_rowid_list)
+    part_bboxes = ibs.get_part_bboxes(part_rowid_list)
+
+    part_rowid_list_ = []
+    part_contours_ = []
+
+    zipped = zip(part_rowid_list, part_contours, part_bboxes)
+    for part_rowid, part_contour, part_bbox in zipped:
+        contour_data = part_contour.get('contour', {})
+        segment = contour_data.get('segment', [])
+
+        if len(segment) > 0:
+            xtl, ytl, w, h = part_bbox
+
+            theta = -1.0 * val * PI / 2
+            bbox = (0.0, 0.0, 1.0, 1.0)
+            R = vt.rotation_around_bbox_mat3x3(theta, bbox)
+
+            for index, point in enumerate(segment):
+                x = point.get('x', None)
+                y = point.get('y', None)
+                r = point.get('r', None)
+                f = point.get('flag', None)
+
+                if None not in [x, y, r, f]:
+                    points = [(x, y)]
+                    xyz_points = vt.add_homogenous_coordinate(np.array(points).T)
+                    trans_points = vt.remove_homogenous_coordinate(R.dot(xyz_points))
+                    new_points = trans_points.T.tolist()
+                    x_, y_ = new_points[0]
+
+                    segment[index]['x'] = x_
+                    segment[index]['y'] = y_
+                    segment[index]['r'] = (r * h) / w
+
+            part_contour['contour']['segment'] = segment
+
+            part_rowid_list_.append(part_rowid)
+            part_contours_.append(part_contour)
+
+    ibs.set_part_contour(part_rowid_list_, part_contours_)
+
 
 @register_ibs_method
 @register_api('/api/part/rotate/left/', methods=['POST'])
@@ -1086,21 +1131,26 @@ def set_part_viewpoints(ibs, part_rowid_list, viewpoint_list):
     ibs.db.set(const.PART_TABLE, ('part_viewpoint',), val_iter, id_iter)
 
 
-# @register_ibs_method
-# @accessor_decors.setter
-# def set_part_tag_text(ibs, part_rowid_list, part_tags_list, duplicate_behavior='error'):
-#     r""" part_tags_list -> part.part_tags[part_rowid_list]
+@register_ibs_method
+@accessor_decors.setter
+def set_part_tag_text(ibs, part_rowid_list, part_tags_list, duplicate_behavior='error'):
+    r"""part_tags_list -> part.part_tags[part_rowid_list]
 
-#     Args:
-#         part_rowid_list
-#         part_tags_list
+    Args:
+        part_rowid_list
+        part_tags_list
 
-#     """
-#     #logger.info('[ibs] set_part_tag_text of part_rowid_list=%r to tags=%r' % (part_rowid_list, part_tags_list))
-#     id_iter = part_rowid_list
-#     colnames = (PART_TAG_TEXT,)
-#     ibs.db.set(const.PART_TABLE, colnames, part_tags_list,
-#                id_iter, duplicate_behavior=duplicate_behavior)
+    """
+    # logger.info('[ibs] set_part_tag_text of part_rowid_list=%r to tags=%r' % (part_rowid_list, part_tags_list))
+    id_iter = part_rowid_list
+    colnames = (PART_TAG_TEXT,)
+    ibs.db.set(
+        const.PART_TABLE,
+        colnames,
+        part_tags_list,
+        id_iter,
+        duplicate_behavior=duplicate_behavior,
+    )
 
 
 @register_ibs_method
@@ -1142,7 +1192,7 @@ def set_part_verts(
         if isinstance(vert_list, np.ndarray):
             verts_list[index] = vert_list.tolist()
     num_verts_list = list(map(len, verts_list))
-    verts_as_strings = list(map(six.text_type, verts_list))
+    verts_as_strings = list(map(str, verts_list))
     id_iter1 = ((part_rowid,) for part_rowid in part_rowid_list)
     # also need to set the internal number of vertices
     val_iter1 = (
@@ -1215,7 +1265,7 @@ def set_part_quality_texts(ibs, part_rowid_list, quality_text_list):
     """
     if not ut.isiterable(part_rowid_list):
         part_rowid_list = [part_rowid_list]
-    if isinstance(quality_text_list, six.string_types):
+    if isinstance(quality_text_list, str):
         quality_text_list = [quality_text_list]
     quality_list = ut.dict_take(const.QUALITY_TEXT_TO_INT, quality_text_list)
     ibs.set_part_qualities(part_rowid_list, quality_list)
@@ -1483,6 +1533,55 @@ def set_part_contour(ibs, part_rowid_list, contour_dict_list):
     ibs.db.set(const.PART_TABLE, ('part_contour_json',), val_list, id_iter)
 
 
+# setting up the Wild Dog data for assigner training
+# def get_corresponding_aids(ibs, part_rowid_list, from_aids=None):
+#     if from_aids is None:
+#         from_aids = ibs.get_valid_aids()
+
+
+# def get_corresponding_aids_slow(ibs, part_rowid_list, from_aids):
+#     part_bboxes = ibs.get_part_bboxes(part_rowid_list)
+#     annot_bboxes = ibs.get_annot_bboxes(from_aids)
+#     annot_gids = ibs.get_annot_gids(from_aids)
+#     from collections import defaultdict
+
+#     bbox_gid_to_aids = defaultdict(int)
+#     for aid, gid, bbox in zip(from_aids, annot_gids, annot_bboxes):
+#         bbox_gid_to_aids[(bbox[0], bbox[1], bbox[2], bbox[3], gid)] = aid
+#     part_gids = ibs.get_part_image_rowids(parts)
+#     part_rowid_to_aid = {
+#         part_id: bbox_gid_to_aids[(bbox[0], bbox[1], bbox[2], bbox[3], gid)]
+#         for part_id, gid, bbox in zip(part_rowid_list, part_gids, part_bboxes)
+#     }
+
+#     part_aids = [part_rowid_to_aid[partid] for partid in parts]
+#     part_parent_aids = ibs.get_part_aids(part_rowid_list)
+
+#     # parents might be non-unique so we gotta make a unique name for each parent
+#     parent_aid_to_part_rowids = defaultdict(list)
+#     for part_rowid, parent_aid in zip(part_rowid_list, part_parent_aids):
+#         parent_aid_to_part_rowids[parent_aid] += [part_rowid]
+
+#     part_annot_names = [
+#         ','.join(str(p) for p in parent_aid_to_part_rowids[parent_aid])
+#         for parent_aid in part_parent_aids
+#     ]
+
+#     # now assign names so we can associate the part annots with the non-part annots
+#     new_part_names = ['part-%s' % part_rowid for part_rowid in part_rowid_list]
+
+
+# def sort_parts_by_tags(ibs, part_rowid_list):
+#     tags = ibs.get_part_tag_text(part_rowid_list)
+#     from collections import defaultdict
+
+#     tag_to_rowids = defaultdict(list)
+#     for tag, part_rowid in zip(tags, part_rowid_list):
+#         tag_to_rowids[tag] += [part_rowid]
+#     parts_by_tags = [tag_to_rowdids[tag] for tag in tag_to_rowdids.keys()]
+#     return parts_by_tags
+
+
 # ==========
 # Testdata
 # ==========
