@@ -33,7 +33,6 @@ Needed Tables:
 
 """
 import logging
-from six.moves import zip
 from wbia import dtool
 import utool as ut
 import numpy as np
@@ -221,7 +220,8 @@ def compute_web_src(depc, gid_list, config=None):
         >>> gid_list = ibs.get_valid_gids()[0:10]
         >>> thumbs = depc.get_property('web_src', gid_list, 'src', recompute=True)
         >>> thumb = thumbs[0]
-        >>> assert ut.hash_data(thumb) == 'qlemvbgbrqljwajkvxpauyioddibeucy'
+        >>> hash_str = ut.hash_data(thumb)
+        >>> assert hash_str in ['yerctlgfqosrhmjpqvkbmnoocagfqsna', 'wcuppmpowkvhfmfcnrxdeedommihexfu'], 'Found %r' % (hash_str, )
     """
     ibs = depc.controller
 
