@@ -72,13 +72,13 @@ import logging  # NOQA
 
 root_logger = logging.getLogger()  # NOQA
 root_logger.setLevel(logging.INFO)  # NOQA
+logging.basicConfig(level=logging.INFO)  # NOQA
 
 import sys  # NOQA
 import numpy as np  # NOQA
 
 from wbia._devscript import devcmd, DEVCMD_FUNCTIONS, DEVPRECMD_FUNCTIONS  # NOQA
 import utool as ut  # NOQA
-from utool.util_six import get_funcname  # NOQA
 import utool  # NOQA
 
 # from wbia.algo.hots import smk
@@ -128,8 +128,6 @@ from wbia import params  # NOQA
 
 print, rrr, profile = utool.inject2(__name__)
 logger = logging.getLogger('wbia')
-
-
 logger.setLevel(logging.INFO)
 
 
@@ -407,7 +405,7 @@ def run_devcmds(ibs, qaid_list, daid_list, acfg=None):
     # Implicit (decorated) test functions
     for (func_aliases, func) in DEVCMD_FUNCTIONS:
         if intest(*func_aliases):
-            funcname = get_funcname(func)
+            funcname = ut.get_funcname(func)
             # with utool.Indenter('[dev.' + funcname + ']'):
             with utool.Timer(funcname):
                 # print('[dev] qid_list=%r' % (qaid_list,))
