@@ -6,10 +6,9 @@ import operator as op
 import utool as ut
 import numpy as np
 import copy
-import six
 
 (print, rrr, profile) = ut.inject2(__name__, '[depbase]')
-logger = logging.getLogger('wbia')
+logger = logging.getLogger('wbia.dtool')
 
 
 class StackedConfig(ut.DictLike, ut.HashComparable):
@@ -56,7 +55,6 @@ class StackedConfig(ut.DictLike, ut.HashComparable):
             raise KeyError(ex)
 
 
-# @six.add_metaclass(ut.HashComparableMetaclass)
 @functools.total_ordering
 class Config(ut.NiceRepr, ut.DictLike):
     r"""
@@ -142,7 +140,7 @@ class Config(ut.NiceRepr, ut.DictLike):
         # self_keys.append(cfg.get_varnames())
         _aliases = cfg._make_key_alias_checker()
         self_keys = set(cfg.keys())
-        for key, val in six.iteritems(kwargs):
+        for key, val in kwargs.items():
             # update only existing keys or namespace prefixed keys
             for k in _aliases(key):
                 if k in self_keys:
@@ -554,7 +552,7 @@ class Config(ut.NiceRepr, ut.DictLike):
             >>> # ENABLE_DOCTEST
             >>> from wbia.dtool.base import *  # NOQA
             >>> from wbia.dtool.example_depcache import DummyKptsConfig
-            >>> from six.moves import cPickle as pickle
+            >>> import pickle
             >>> cfg = DummyKptsConfig()
             >>> ser = pickle.dumps(cfg)
             >>> cfg2 = pickle.loads(ser)
@@ -565,7 +563,7 @@ class Config(ut.NiceRepr, ut.DictLike):
             >>> # ENABLE_DOCTEST
             >>> from wbia.dtool.base import *  # NOQA
             >>> from wbia.dtool.example_depcache import DummyVsManyConfig
-            >>> from six.moves import cPickle as pickle
+            >>> import pickle
             >>> cfg = DummyVsManyConfig()
             >>> state = cfg.__getstate__()
             >>> cfg2 = DummyVsManyConfig()
@@ -859,7 +857,7 @@ class BaseRequest(IBEISRequestHacks, ut.NiceRepr):
         result_list = table.get_row_data(rowids)
         if postprocess and hasattr(request, 'postprocess_execute'):
             logger.info('Converting results')
-            result_list = request.postprocess_execute(parent_rowids, result_list)
+            result_list = request.postprocess_execute(table, parent_rowids, result_list)
             pass
         return result_list
 
@@ -942,7 +940,7 @@ class VsOneSimilarityRequest(BaseRequest, AnnotSimiliarity):
     def parent_rowids_T(request):
         return ut.list_transpose(request.parent_rowids)
 
-    def execute(request, parent_rowids=None, use_cache=None, postprocess=True):
+    def execute(request, parent_rowids=None, use_cache=None, postprocess=True, **kwargs):
         """ HACKY REIMPLEMENTATION """
         ut.colorprint('[req] Executing request %s' % (request,), 'yellow')
         table = request.depc[request.tablename]
@@ -980,8 +978,9 @@ class VsOneSimilarityRequest(BaseRequest, AnnotSimiliarity):
 
         if postprocess and hasattr(request, 'postprocess_execute'):
             logger.info('Converting results')
-            result_list = request.postprocess_execute(parent_rowids, result_list)
-            pass
+            result_list = request.postprocess_execute(
+                table, parent_rowids, rowids, result_list
+            )
         return result_list
 
     def get_input_hashid(request):
