@@ -2,11 +2,10 @@
 import logging
 import utool as ut
 import numpy as np
-import six
 import networkx as nx  # NOQA
 
 (print, rrr, profile) = ut.inject2(__name__, '[depc_input_helpers]')
-logger = logging.getLogger('wbia')
+logger = logging.getLogger('wbia.dtool')
 
 
 class BranchId(ut.HashComparable):
@@ -213,7 +212,7 @@ def make_expanded_input_graph(graph, target):
         return accum_ids
 
     sources = list(ut.nx_source_nodes(graph))
-    logger.info(sources)
+    # logger.info(sources)
     # assert len(sources) == 1, 'expected a unique source'
     source = sources[0]
 
@@ -611,7 +610,7 @@ class TableInput(ut.NiceRepr):
             >>> assert 'indexer' not in str(inputs2), (
             >>>     '(2) unexpected indexer in %s' % (inputs2,))
         """
-        if isinstance(index, six.string_types):
+        if isinstance(index, str):
             index_list = ut.where([rmi.tablename == index for rmi in inputs.rmi_list])
             if len(index_list) == 0:
                 index = 0
