@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 """Mapping of Python types to SQL types"""
 import io
-import json
 import uuid
 
 import numpy as np
+from utool.util_cache import from_json, to_json
+import sqlalchemy
+from sqlalchemy.sql import text
 from sqlalchemy.types import Integer as SAInteger
 from sqlalchemy.types import TypeDecorator, UserDefinedType
 
@@ -40,6 +42,7 @@ class JSONCodeableType(UserDefinedType):
     # Abstract properties
     base_py_type = None
     col_spec = None
+    postgresql_base_type = 'json'
 
     def get_col_spec(self, **kw):
         return self.col_spec
@@ -47,12 +50,9 @@ class JSONCodeableType(UserDefinedType):
     def bind_processor(self, dialect):
         def process(value):
             if value is None:
-                return value
+                return None
             else:
-                if isinstance(value, self.base_py_type):
-                    return json.dumps(value)
-                else:
-                    return value
+                return to_json(value)
 
         return process
 
@@ -60,11 +60,11 @@ class JSONCodeableType(UserDefinedType):
         def process(value):
             if value is None:
                 return value
+            elif dialect.name == 'postgresql':
+                # postgresql doesn't need the value to be json decoded
+                return value
             else:
-                if not isinstance(value, self.base_py_type):
-                    return json.loads(value)
-                else:
-                    return value
+                return from_json(value)
 
         return process
 
@@ -74,6 +74,7 @@ class NumPyPicklableType(UserDefinedType):
     # Abstract properties
     base_py_types = None
     col_spec = None
+    postgresql_base_type = 'bytea'
 
     def get_col_spec(self, **kw):
         return self.col_spec
@@ -118,8 +119,11 @@ class Dict(JSONCodeableType):
 class Integer(TypeDecorator):
     impl = SAInteger
 
+    cache_ok = True
+
     def process_bind_param(self, value, dialect):
-        return int(value)
+        if value is not None:
+            return int(value)
 
 
 class List(JSONCodeableType):
@@ -159,12 +163,20 @@ class UUID(UserDefinedType):
         def process(value):
             if value is None:
                 return value
+            if not isinstance(value, uuid.UUID):
+                value = uuid.UUID(value)
+
+            if dialect.name == 'sqlite':
+                return value.bytes_le
+            elif dialect.name == 'postgresql':
+                return value
             else:
                 if not isinstance(value, uuid.UUID):
-                    return '%.32x' % uuid.UUID(value).int
+                    return uuid.UUID(value).bytes_le
                 else:
                     # hexstring
-                    return '%.32x' % value.int
+                    return value.bytes_le
+                raise RuntimeError(f'Unknown dialect {dialect.name}')
 
         return process
 
@@ -172,11 +184,15 @@ class UUID(UserDefinedType):
         def process(value):
             if value is None:
                 return value
-            else:
+            if dialect.name == 'sqlite':
                 if not isinstance(value, uuid.UUID):
-                    return uuid.UUID(value)
+                    return uuid.UUID(bytes_le=value)
                 else:
                     return value
+            elif dialect.name == 'postgresql':
+                return value
+            else:
+                raise RuntimeError(f'Unknown dialect {dialect.name}')
 
         return process
 
@@ -184,3 +200,25 @@ class UUID(UserDefinedType):
 _USER_DEFINED_TYPES = (Dict, List, NDArray, Number, UUID)
 # SQL type (e.g. 'DICT') to SQLAlchemy type:
 SQL_TYPE_TO_SA_TYPE = {cls().get_col_spec(): cls for cls in _USER_DEFINED_TYPES}
+# Map postgresql types to SQLAlchemy types (postgresql type names are lowercase)
+SQL_TYPE_TO_SA_TYPE.update(
+    {cls().get_col_spec().lower(): cls for cls in _USER_DEFINED_TYPES}
+)
+SQL_TYPE_TO_SA_TYPE['INTEGER'] = Integer
+SQL_TYPE_TO_SA_TYPE['integer'] = Integer
+SQL_TYPE_TO_SA_TYPE['bigint'] = Integer
+
+
+def initialize_postgresql_types(conn, schema):
+    domain_names = conn.execute(
+        """\
+        SELECT domain_name FROM information_schema.domains
+        WHERE domain_schema = (select current_schema)"""
+    ).fetchall()
+    for type_name, cls in SQL_TYPE_TO_SA_TYPE.items():
+        if type_name not in domain_names and hasattr(cls, 'postgresql_base_type'):
+            base_type = cls.postgresql_base_type
+            try:
+                conn.execute(f'CREATE DOMAIN {type_name} AS {base_type}')
+            except sqlalchemy.exc.ProgrammingError:
+                conn.execute(text('SET SCHEMA :schema'), schema=schema)
