@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
 import logging
 import warnings
-from six.moves import zip, range, zip_longest
 from . import draw_func2 as df2
-import six
-from six.moves import reduce
+from itertools import zip_longest
+from functools import reduce
 import scipy.stats
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -89,7 +88,7 @@ def multi_plot(xdata=None, ydata_list=[], **kwargs):
 
     if isinstance(ydata_list, dict):
         # Special case where ydata is a dictionary
-        if isinstance(xdata, six.string_types):
+        if isinstance(xdata, str):
             # Special-er case where xdata is specified in ydata
             xkey = xdata
             ykeys = ut.setdiff(ydata_list.keys(), [xkey])
@@ -442,11 +441,9 @@ def multi_plot(xdata=None, ydata_list=[], **kwargs):
     ymin = kwargs.get('ymin', ax.get_ylim()[0])
     ymax = kwargs.get('ymax', ax.get_ylim()[1])
 
-    text_type = six.text_type
-
-    if text_type(xmax) == 'data':
+    if str(xmax) == 'data':
         xmax = max([xd.max() for xd in xdata_list])
-    if text_type(xmin) == 'data':
+    if str(xmin) == 'data':
         xmin = min([xd.min() for xd in xdata_list])
 
     # Setup axes ticks
@@ -1302,7 +1299,7 @@ def plot_score_histograms(
             title = 'Histogram of ' + score_label + 's'
     title += kwargs.get('titlesuf', '')
     if score_lbls is None:
-        score_lbls = [six.text_type(lblx) for lblx in range(len(scores_list))]
+        score_lbls = [str(lblx) for lblx in range(len(scores_list))]
     if score_markers is None:
         score_markers = ['o' for lblx in range(len(scores_list))]
     if score_colors is None:
@@ -1962,16 +1959,15 @@ def interval_stats_plot(
     """
     if fnum is None:
         fnum = df2.next_fnum()
-    import six
 
-    x_data = np.array(list(six.iterkeys(param2_stat_dict)))
+    x_data = np.array(list(param2_stat_dict.keys()))
     sortx = x_data.argsort()
     x_data_sort = x_data[sortx]
     from matplotlib import pyplot as plt
 
     # Prepare y data for boxplot
     y_data_keys = ['std', 'mean', 'max', 'min']
-    y_data_dict = list(six.itervalues(param2_stat_dict))
+    y_data_dict = list(param2_stat_dict.values())
 
     def get_dictlist_key(dict_list, key):
         return [dict_[key] for dict_ in dict_list]
