@@ -289,8 +289,12 @@ def double_depcache_graph():
         'CurvRankDorsal': 'CurvRank (Dorsal) Distance',
         'CurvRankFinfindrHybridDorsal': 'CurvRank + FinFindR Hybrid (Dorsal) Distance',
         'CurvRankFluke': 'CurvRank (Fluke) Distance',
+        'CurvRankTwo': 'CurvRank V2 Distance',
+        'CurvRankTwoDorsal': 'CurvRank V2 (Dorsal) Distance',
+        'CurvRankTwoFluke': 'CurvRank V2 (Fluke) Distance',
         'Deepsense': 'Deepsense Distance',
         'Pie': 'Pie Distance',
+        'PieTwo': 'Pie v2 Distance',
         'Finfindr': 'Finfindr Distance',
         'Kaggle7': 'Kaggle7 Distance',
         'KaggleSeven': 'Kaggle7 Distance',
@@ -316,8 +320,12 @@ def double_depcache_graph():
         'CurvRankDorsal': 'curvrank_distance_dorsal',
         'CurvRankFinfindrHybridDorsal': 'curvrank_finfindr_hybrid_distance_dorsal',
         'CurvRankFluke': 'curvrank_distance_fluke',
+        'CurvRankTwo': 'curvrank_two_distance',
+        'CurvRankTwoDorsal': 'curvrank_two_distance_dorsal',
+        'CurvRankTwoFluke': 'curvrank_two_distance_fluke',
         'Deepsense': 'deepsense_distance',
         'Pie': 'pie_distance',
+        'PieTwo': 'pie_v2_distance',
         'Finfindr': 'finfindr_distance',
         'Kaggle7': 'kaggle7_distance',
         'KaggleSeven': 'kaggle7_distance',
