@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 import logging
-import six
-from six.moves import zip, map
 import numpy as np
 import vtool as vt
 import utool as ut
@@ -169,13 +167,11 @@ def rename_and_reduce_tags(ibs, annotmatch_rowids):
     tags_list_ = get_annotmatch_case_tags(ibs, annotmatch_rowids)
 
     def fix_tags(tags):
-        return {six.text_type(t.lower()) for t in tags}
+        return {str(t.lower()) for t in tags}
 
     tags_list = list(map(fix_tags, tags_list_))
 
-    prop_mapping = {
-        six.text_type(key.lower()): val for key, val in six.iteritems(PROP_MAPPING)
-    }
+    prop_mapping = {str(key.lower()): val for key, val in PROP_MAPPING.items()}
 
     bad_tags = fix_tags(prop_mapping.keys())
 
@@ -517,7 +513,7 @@ def filterflags_general_tags(
     import operator
 
     def fix_tags(tags):
-        return {six.text_type(t.lower()) for t in tags}
+        return {str(t.lower()) for t in tags}
 
     if logic is None:
         logic = 'and'
@@ -571,13 +567,9 @@ def filterflags_general_tags(
             logic_func(flags, flags_, out=flags)
         return flags
 
-    flags = execute_filter(
-        flags, tags_list, any_startswith, operator.gt, six.text_type.startswith
-    )
+    flags = execute_filter(flags, tags_list, any_startswith, operator.gt, str.startswith)
 
-    flags = execute_filter(
-        flags, tags_list, any_endswith, operator.gt, six.text_type.endswith
-    )
+    flags = execute_filter(flags, tags_list, any_endswith, operator.gt, str.endswith)
 
     flags = execute_filter(
         flags, tags_list, any_match, operator.gt, lambda t, f: re.match(f, t)
@@ -640,7 +632,7 @@ def get_annotmatch_case_tags(ibs, annotmatch_rowids):
     #        flag_list = ibs.get_annotmatch_prop(case, annotmatch_rowids)
     #        for tags in ut.compress(tags_list, flag_list):
     #            tags.append(case)
-    tags_list = [[six.text_type(t) for t in tags] for tags in tags_list]
+    tags_list = [[str(t) for t in tags] for tags in tags_list]
     # if ut.get_argval('--consol') or True:
     #    tags_list = consolodate_annotmatch_tags(tags_list)
     return tags_list
@@ -855,7 +847,7 @@ def append_annot_case_tags(ibs, aid_list, tag_list):
     """
     # Ensure each item is a list
     # tags_list = [tag if isinstance(tag, list) else [tag] for tag in tag_list]
-    if isinstance(tag_list, six.string_types):
+    if isinstance(tag_list, str):
         # Apply single tag to everybody
         tag_list = [tag_list] * len(aid_list)
     tags_list = [ut.ensure_iterable(tag) for tag in tag_list]
@@ -878,7 +870,7 @@ def set_annot_case_tags(ibs, aid_list, new_tags_list):
 
 @register_ibs_method
 def remove_annot_case_tags(ibs, aid_list, tag_list):
-    if isinstance(tag_list, six.string_types):
+    if isinstance(tag_list, str):
         # Apply single tag to everybody
         tag_list = [tag_list] * len(aid_list)
     tags_list = [ut.ensure_iterable(tag) for tag in tag_list]
