@@ -7,14 +7,12 @@ from os.path import join, exists
 import zipfile
 import time
 from io import BytesIO
-from six.moves import cStringIO as StringIO
 from flask import request, current_app, send_file
 from wbia.control import controller_inject
 from wbia.web import appfuncs as appf
 import utool as ut
 import vtool as vt
 import uuid as uuid_module
-import six
 from wbia.web.app import PROMETHEUS
 
 print, rrr, profile = ut.inject2(__name__)
@@ -31,29 +29,20 @@ register_route = controller_inject.get_wbia_flask_route(__name__)
 @register_api('/api/embed/', methods=['GET'])
 def web_embed(*args, **kwargs):
     ibs = current_app.ibs  # NOQA
-
-    if False:
-        from wbia.algo.graph.state import POSTV
-
-        payload = {
-            'action': 'update_task_thresh',
-            'task': 'match_state',
-            'decision': POSTV,
-            'value': 0.95,
-        }
-
-        for graph_uuid in current_app.GRAPH_CLIENT_DICT:
-            graph_client = current_app.GRAPH_CLIENT_DICT.get(graph_uuid, None)
-            if graph_client is None:
-                continue
-            if len(graph_client.futures) > 0:
-                continue
-            future = graph_client.post(payload)  # NOQA
-            # future.result()  # Guarantee that this has happened before calling refresh
-
     ut.embed()
 
 
+@register_route(
+    '/api/image/src/<rowid>.jpg',
+    methods=['GET'],
+    __route_prefix_check__=False,
+    __route_postfix_check__=False,
+    __route_authenticate__=False,
+)
+def image_src_api_ext(*args, **kwargs):
+    return image_src_api(*args, **kwargs)
+
+
 # Special function that is a route only to ignore the JSON response, but is
 # actually (and should be) an API call
 @register_route(
@@ -67,12 +56,12 @@ def image_src_api(rowid=None, thumbnail=False, fresh=False, **kwargs):
     Returns the image file of image <gid>
 
     Example:
-        >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.web.app import *  # NOQA
         >>> import wbia
-        >>> with wbia.opendb_bg_web('testdb1', start_job_queue=False, managed=True) as web_ibs:
-        ...     resp = web_ibs.send_wbia_request('/api/image/src/1/', type_='get', json=False)
-        >>> print(resp)
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     resp = client.get('/api/image/src/1/')
+        >>> print(resp.data)
+        b'\xff\xd8\xff\xe0\x00\x10JFIF...
 
     RESTful:
         Method: GET
@@ -95,16 +84,14 @@ def image_src_api(rowid=None, thumbnail=False, fresh=False, **kwargs):
 
     # Load image
     assert gpath is not None, 'image path should not be None'
-    image = vt.imread(gpath, orient='auto')
+    orient = ibs.get_image_orientation(rowid)
+    image = vt.imread(gpath, orient=orient)
     image = appf.resize_via_web_parameters(image)
     image = image[:, :, ::-1]
 
     # Encode image
     image_pil = Image.fromarray(image)
-    if six.PY2:
-        img_io = StringIO()
-    else:
-        img_io = BytesIO()
+    img_io = BytesIO()
     image_pil.save(img_io, 'JPEG', quality=100)
     img_io.seek(0)
     return send_file(img_io, mimetype='image/jpeg')
@@ -125,12 +112,13 @@ def annot_src_api(rowid=None, fresh=False, **kwargs):
 
     Example:
         >>> # xdoctest: +REQUIRES(--slow)
-        >>> # WEB_DOCTEST
+        >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.web.app import *  # NOQA
         >>> import wbia
-        >>> with wbia.opendb_bg_web('testdb1', start_job_queue=False, managed=True) as web_ibs:
-        ...     resp = web_ibs.send_wbia_request('/api/annot/src/1/', type_='get', json=False)
-        >>> print(resp)
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     resp = client.get('/api/annot/src/1/')
+        >>> print(resp.data)
+        b'\xff\xd8\xff\xe0\x00\x10JFIF...
 
     RESTful:
         Method: GET
@@ -149,10 +137,7 @@ def annot_src_api(rowid=None, fresh=False, **kwargs):
 
     # Encode image
     image_pil = Image.fromarray(image)
-    if six.PY2:
-        img_io = StringIO()
-    else:
-        img_io = BytesIO()
+    img_io = BytesIO()
     image_pil.save(img_io, 'JPEG', quality=100)
     img_io.seek(0)
     return send_file(img_io, mimetype='image/jpeg')
@@ -173,12 +158,13 @@ def background_src_api(rowid=None, fresh=False, **kwargs):
 
     Example:
         >>> # xdoctest: +REQUIRES(--slow)
-        >>> # WEB_DOCTEST
+        >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.web.app import *  # NOQA
         >>> import wbia
-        >>> with wbia.opendb_bg_web('testdb1', start_job_queue=False, managed=True) as web_ibs:
-        ...     resp = web_ibs.send_wbia_request('/api/background/src/1/', type_='get', json=False)
-        >>> print(resp)
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     resp = client.get('/api/background/src/1/')
+        >>> print(resp.data)
+        b'\xff\xd8\xff\xe0\x00\x10JFIF...
 
     RESTful:
         Method: GET
@@ -197,10 +183,7 @@ def background_src_api(rowid=None, fresh=False, **kwargs):
 
     # Encode image
     image_pil = Image.fromarray(image)
-    if six.PY2:
-        img_io = StringIO()
-    else:
-        img_io = BytesIO()
+    img_io = BytesIO()
     image_pil.save(img_io, 'JPEG', quality=100)
     img_io.seek(0)
     return send_file(img_io, mimetype='image/jpeg')
@@ -223,9 +206,10 @@ def image_src_api_json(uuid=None, **kwargs):
         >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.web.app import *  # NOQA
         >>> import wbia
-        >>> with wbia.opendb_bg_web('testdb1', start_job_queue=False, managed=True) as web_ibs:
-        ...     resp = web_ibs.send_wbia_request('/api/image/src/json/0a9bc03d-a75e-8d14-0153-e2949502aba7/', type_='get', json=False)
-        >>> print(resp)
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     resp = client.get('/api/image/src/json/0a9bc03d-a75e-8d14-0153-e2949502aba7/')
+        >>> print(resp.data)
+        b'\xff\xd8\xff\xe0\x00\x10JFIF...
 
     RESTful:
         Method: GET
@@ -233,7 +217,7 @@ def image_src_api_json(uuid=None, **kwargs):
     """
     ibs = current_app.ibs
     try:
-        if isinstance(uuid, six.string_types):
+        if isinstance(uuid, str):
             uuid = uuid_module.UUID(uuid)
     except Exception:
         from wbia.control.controller_inject import translate_wbia_webreturn
@@ -284,7 +268,7 @@ def image_conv_feature_api_json(uuid=None, model='resnet50', **kwargs):
     ibs = current_app.ibs
 
     try:
-        if isinstance(uuid, six.string_types):
+        if isinstance(uuid, str):
             uuid = uuid_module.UUID(uuid)
         assert uuid is not None
     except Exception:
@@ -425,37 +409,21 @@ def image_upload_zip(**kwargs):
 @register_api('/api/test/helloworld/', methods=['GET', 'POST', 'DELETE', 'PUT'])
 def hello_world(*args, **kwargs):
     """
-    CommandLine:
-        python -m wbia.web.apis --exec-hello_world:0
-        python -m wbia.web.apis --exec-hello_world:1
 
     Example:
-        >>> # xdoctest: +REQUIRES(--web-tests)
-        >>> from wbia.web.app import *  # NOQA
-        >>> import wbia
-        >>> web_ibs = wbia.opendb_bg_web(browser=True, start_job_queue=False, url_suffix='/api/test/helloworld/?test0=0')  # start_job_queue=False)
-        >>> print('web_ibs = %r' % (web_ibs,))
-        >>> print('Server will run until control c')
-        >>> web_ibs.terminate2()
-
-    Example1:
         >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.web.app import *  # NOQA
         >>> import wbia
         >>> import requests
         >>> import wbia
-        >>> with wbia.opendb_bg_web('testdb1', start_job_queue=False, managed=True) as web_ibs:
-        ...     web_port = ibs.get_web_port_via_scan()
-        ...     if web_port is None:
-        ...         raise ValueError('IA web server is not running on any expected port')
-        ...     domain = 'http://127.0.0.1:%s' % (web_port, )
-        ...     url = domain + '/api/test/helloworld/?test0=0'
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     resp = client.get('/api/test/helloworld/?test0=0')
         ...     payload = {
         ...         'test1' : 'test1',
         ...         'test2' : None,  # NOTICE test2 DOES NOT SHOW UP
         ...     }
-        ...     resp = requests.post(url, data=payload)
-        ...     print(resp)
+        ...     resp = client.post('/api/test/helloworld/', data=payload)
+
     """
     logger.info('+------------ HELLO WORLD ------------')
     logger.info('Args: %r' % (args,))
