@@ -4,7 +4,6 @@
 #    import os
 #    os.environ['UTOOL_NOCNN'] = 'True'
 import logging
-import six
 import utool as ut
 import uuid  # NOQA
 from wbia.control import controller_inject
@@ -43,7 +42,7 @@ def ensure_simple_server(port=5832):
 
 
 def ensure_uuid_list(list_):
-    if list_ is not None and len(list_) > 0 and isinstance(list_[0], six.string_types):
+    if list_ is not None and len(list_) > 0 and isinstance(list_[0], str):
         list_ = list(map(uuid.UUID, list_))
     return list_
 
@@ -57,7 +56,7 @@ def web_check_annot_uuids_with_names(annot_uuid_list, name_list):
     annot_dict = {}
     zipped = zip(annot_uuid_list, name_list)
     for index, (annot_uuid, name) in enumerate(zipped):
-        if not isinstance(annot_uuid, (uuid.UUID, six.string_types)):
+        if not isinstance(annot_uuid, (uuid.UUID, str)):
             raise ValueError(
                 'Received UUID %r that is not a UUID or string at index %s'
                 % (annot_uuid, index)
@@ -197,6 +196,7 @@ def start_identify_annots(
     callback_url=None,
     callback_method=None,
     lane='slow',
+    jobid=None,
 ):
     r"""
     REST:
@@ -262,6 +262,7 @@ def start_identify_annots(
 
     Example:
         >>> # xdoctest: +REQUIRES(--web-tests)
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
         >>> from wbia.web.apis_engine import *  # NOQA
         >>> import wbia
         >>> with wbia.opendb_bg_web('testdb1', managed=True) as web_ibs:  # , domain='http://52.33.105.88')
@@ -322,7 +323,7 @@ def start_identify_annots(
     )
     args = (qaid_list, daid_list, pipecfg)
     jobid = ibs.job_manager.jobiface.queue_job(
-        'query_chips_simple_dict', callback_url, callback_method, lane, *args
+        'query_chips_simple_dict', callback_url, callback_method, lane, jobid, *args
     )
 
     # if callback_url is not None:
@@ -345,6 +346,7 @@ def start_identify_annots_query_complete(
     callback_url=None,
     callback_method=None,
     lane='slow',
+    jobid=None,
 ):
     r"""
     REST:
@@ -399,7 +401,7 @@ def start_identify_annots_query_complete(
         k,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'query_chips_graph_complete', callback_url, callback_method, lane, *args
+        'query_chips_graph_complete', callback_url, callback_method, lane, jobid, *args
     )
     return jobid
 
@@ -414,6 +416,7 @@ def start_identify_annots_query(
     database_annot_uuid_list=None,
     # database_annot_name_uuid_list=None,
     database_annot_name_list=None,
+    database_imgsetid=None,
     matching_state_list=[],
     query_config_dict={},
     echo_query_params=True,
@@ -421,6 +424,7 @@ def start_identify_annots_query(
     callback_url=None,
     callback_method=None,
     lane='slow',
+    jobid=None,
 ):
     r"""
     REST:
@@ -452,6 +456,7 @@ def start_identify_annots_query(
 
     Example:
         >>> # DISABLE_DOCTEST
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
         >>> from wbia.web.apis_engine import *  # NOQA
         >>> import wbia
         >>> #domain = 'localhost'
@@ -474,7 +479,7 @@ def start_identify_annots_query(
         ...     result_response = web_ibs.read_engine_results(jobid)
         ...     print('result_response = %s' % (ut.repr3(result_response),))
         ...     inference_result = result_response['json_result']
-        ...     if isinstance(inference_result, six.string_types):
+        ...     if isinstance(inference_result, str):
         ...        print(inference_result)
         ...     cm_dict = inference_result['cm_dict']
         ...     quuid = quuid_list[0]
@@ -512,6 +517,16 @@ def start_identify_annots_query(
     dname_list = database_annot_name_list
     qname_list = query_annot_name_list
 
+    if database_imgsetid is not None:
+        all_imgsetids = set(ibs.get_valid_imgsetids())
+        if database_imgsetid not in all_imgsetids:
+            database_imgsetid = None
+
+    if database_imgsetid is not None:
+        assert database_annot_uuid_list is None
+        daid_list = ibs.get_imageset_aids(database_imgsetid)
+        database_annot_uuid_list = ibs.get_annot_uuids(daid_list)
+
     # Check inputs
     assert (
         len(query_annot_uuid_list) == 1
@@ -533,6 +548,8 @@ def start_identify_annots_query(
         'curvrankdorsal',
         'curvrankfinfindrhybriddorsal',
         'curvrankfluke',
+        'curvranktwodorsal',
+        'curvranktwofluke',
     ):
         curvrank_daily_tag = query_config_dict.get('curvrank_daily_tag', '')
         if len(curvrank_daily_tag) > 144:
@@ -623,7 +640,7 @@ def start_identify_annots_query(
     )
     args = (qaid_list, daid_list, user_feedback, query_config_dict, echo_query_params)
     jobid = ibs.job_manager.jobiface.queue_job(
-        'query_chips_graph', callback_url, callback_method, lane, *args
+        'query_chips_graph', callback_url, callback_method, lane, jobid, *args
     )
     return jobid
 
@@ -631,7 +648,13 @@ def start_identify_annots_query(
 @register_ibs_method
 @register_api('/api/engine/wic/cnn/', methods=['POST'])
 def start_wic_image(
-    ibs, image_uuid_list, callback_url=None, callback_method=None, lane='fast', **kwargs
+    ibs,
+    image_uuid_list,
+    callback_url=None,
+    callback_method=None,
+    lane='fast',
+    jobid=None,
+    **kwargs
 ):
     """
     REST:
@@ -655,7 +678,7 @@ def start_wic_image(
         kwargs,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'wic_cnn_json', callback_url, callback_method, lane, *args
+        'wic_cnn_json', callback_url, callback_method, lane, jobid, *args
     )
 
     # if callback_url is not None:
@@ -668,7 +691,13 @@ def start_wic_image(
 @register_ibs_method
 @register_api('/api/engine/detect/cnn/yolo/', methods=['POST'])
 def start_detect_image_yolo(
-    ibs, image_uuid_list, callback_url=None, callback_method=None, lane='fast', **kwargs
+    ibs,
+    image_uuid_list,
+    callback_url=None,
+    callback_method=None,
+    lane='fast',
+    jobid=None,
+    **kwargs
 ):
     """
     REST:
@@ -692,7 +721,7 @@ def start_detect_image_yolo(
         kwargs,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'detect_cnn_yolo_json', callback_url, callback_method, lane, *args
+        'detect_cnn_yolo_json', callback_url, callback_method, lane, jobid, *args
     )
 
     # if callback_url is not None:
@@ -705,7 +734,13 @@ def start_detect_image_yolo(
 @register_ibs_method
 @register_api('/api/engine/labeler/cnn/', methods=['POST'])
 def start_labeler_cnn(
-    ibs, annot_uuid_list, callback_url=None, callback_method=None, lane='fast', **kwargs
+    ibs,
+    annot_uuid_list,
+    callback_url=None,
+    callback_method=None,
+    lane='fast',
+    jobid=None,
+    **kwargs
 ):
     # Check UUIDs
     ibs.web_check_uuids(qannot_uuid_list=annot_uuid_list)
@@ -721,7 +756,7 @@ def start_labeler_cnn(
         kwargs,
     )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'labeler_cnn', callback_url, callback_method, lane, *args
+        'labeler_cnn', callback_url, callback_method, lane, jobid, *args
     )
 
     # if callback_url is not None:
@@ -734,7 +769,14 @@ def start_labeler_cnn(
 @register_ibs_method
 @register_api('/api/engine/review/query/chip/best/', methods=['POST'])
 def start_review_query_chips_best(
-    ibs, annot_uuid, callback_url=None, callback_method=None, lane='slow', **kwargs
+    ibs,
+    annot_uuid,
+    database_imgsetid=None,
+    callback_url=None,
+    callback_method=None,
+    lane='slow',
+    jobid=None,
+    **kwargs
 ):
     annot_uuid_list = [annot_uuid]
 
@@ -747,9 +789,12 @@ def start_review_query_chips_best(
     annot_uuid_list = ensure_uuid_list(annot_uuid_list)
     aid_list = ibs.get_annot_aids_from_uuid(annot_uuid_list)
     aid = aid_list[0]
-    args = (aid,)
+    args = (
+        aid,
+        database_imgsetid,
+    )
     jobid = ibs.job_manager.jobiface.queue_job(
-        'review_query_chips_best', callback_url, callback_method, lane, *args
+        'review_query_chips_best', callback_url, callback_method, lane, jobid, *args
     )
 
     # if callback_url is not None:
@@ -775,7 +820,14 @@ def start_detect_image_test_yolo(ibs):
 @register_ibs_method
 @register_api('/api/engine/detect/cnn/lightnet/', methods=['POST', 'GET'])
 def start_detect_image_lightnet(
-    ibs, image_uuid_list, callback_url=None, callback_method=None, lane='fast', **kwargs
+    ibs,
+    image_uuid_list,
+    callback_url=None,
+    callback_method=None,
+    callback_detailed=False,
+    lane='fast',
+    jobid=None,
+    **kwargs
 ):
     """
     REST:
@@ -783,24 +835,46 @@ def start_detect_image_lightnet(
         URL:
 
     Args:
-        image_uuid_list (list) : list of image uuids to detect on.
+        image_uuid_list (list) : list of image uuids or urls to detect on.
         callback_url (url) : url that will be called when detection succeeds or fails
     """
-    # Check UUIDs
-    ibs.web_check_uuids(image_uuid_list=image_uuid_list)
+    if image_uuid_list and '://' not in image_uuid_list[0]:
+        # Check UUIDs
+        ibs.web_check_uuids(image_uuid_list=image_uuid_list)
 
-    # import wbia
-    # from wbia.web import apis_engine
-    # ibs.load_plugin_module(apis_engine)
-    image_uuid_list = ensure_uuid_list(image_uuid_list)
-    gid_list = ibs.get_image_gids_from_uuid(image_uuid_list)
-    args = (
-        gid_list,
-        kwargs,
-    )
-    jobid = ibs.job_manager.jobiface.queue_job(
-        'detect_cnn_lightnet_json', callback_url, callback_method, lane, *args
-    )
+        # import wbia
+        # from wbia.web import apis_engine
+        # ibs.load_plugin_module(apis_engine)
+        image_uuid_list = ensure_uuid_list(image_uuid_list)
+        gid_list = ibs.get_image_gids_from_uuid(image_uuid_list)
+        args = (
+            gid_list,
+            kwargs,
+        )
+        jobid = ibs.job_manager.jobiface.queue_job(
+            'detect_cnn_lightnet_json',
+            callback_url,
+            callback_method,
+            callback_detailed,
+            lane,
+            jobid,
+            *args
+        )
+    else:
+        # image_uuid_list contains urls
+        args = (
+            image_uuid_list,
+            kwargs,
+        )
+        jobid = ibs.job_manager.jobiface.queue_job(
+            'detect_cnn_lightnet_image_uris_json',
+            callback_url,
+            callback_method,
+            callback_detailed,
+            lane,
+            jobid,
+            *args
+        )
 
     # if callback_url is not None:
     #    #import requests
@@ -825,7 +899,13 @@ def start_detect_image_test_lightnet(ibs):
 @register_ibs_method
 @register_api('/api/engine/classify/whaleshark/injury/', methods=['POST'])
 def start_predict_ws_injury_interim_svm(
-    ibs, annot_uuid_list, callback_url=None, callback_method=None, lane='fast', **kwargs
+    ibs,
+    annot_uuid_list,
+    callback_url=None,
+    callback_method=None,
+    lane='fast',
+    jobid=None,
+    **kwargs
 ):
     """
     REST:
@@ -866,7 +946,7 @@ def start_predict_ws_injury_interim_svm(
     annots = ibs.annots(uuids=annot_uuid_list)
     args = (annots.aids,)
     jobid = ibs.job_manager.jobiface.queue_job(
-        'predict_ws_injury_interim_svm', callback_url, callback_method, lane, *args
+        'predict_ws_injury_interim_svm', callback_url, callback_method, lane, jobid, *args
     )
 
     # if callback_url is not None:
