@@ -3,7 +3,7 @@
 Dependencies: flask, tornado
 
 SeeAlso:
-    routes.turk_identification
+    routes.review_identification
 """
 import logging
 from wbia.control import controller_inject
@@ -17,7 +17,6 @@ from wbia.web import appfuncs as appf
 from wbia import constants as const
 import traceback
 import requests
-import six
 from datetime import datetime
 
 (print, rrr, profile) = ut.inject2(__name__)
@@ -176,7 +175,7 @@ def process_graph_match_html(ibs, **kwargs):
             tag_list.append(checbox_tag)
     tag_list = sorted(set(tag_list))
     confidence_default = const.CONFIDENCE.INT_TO_CODE[const.CONFIDENCE.UNKNOWN]
-    confidence = request.form.get('ia-turk-confidence', confidence_default)
+    confidence = request.form.get('ia-review-confidence', confidence_default)
     if confidence not in const.CONFIDENCE.CODE_TO_INT.keys():
         confidence = confidence_default
     if len(tag_list) == 0:
@@ -325,6 +324,9 @@ def review_graph_match_html(
 
     Example:
         >>> # xdoctest: +REQUIRES(--web-tests)
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
+        >>> # DISABLE_DOCTEST
+        >>> # Disabled because this test uses opendb_bg_web, which hangs the test runner and leaves zombie processes
         >>> from wbia.web.apis_query import *  # NOQA
         >>> import wbia
         >>> web_ibs = wbia.opendb_bg_web('testdb1')  # , domain='http://52.33.105.88')
@@ -377,6 +379,7 @@ def review_graph_match_html(
 
     Example2:
         >>> # DISABLE_DOCTEST
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
         >>> # This starts off using web to get information, but finishes the rest in python
         >>> from wbia.web.apis_query import *  # NOQA
         >>> import wbia
@@ -433,11 +436,14 @@ def review_graph_match_html(
         'curvrankdorsal',
         'curvrankfinfindrhybriddorsal',
         'curvrankfluke',
+        'curvranktwodorsal',
+        'curvranktwofluke',
         'deepsense',
         'finfindr',
         'kaggle7',
         'kaggleseven',
         'pie',
+        'pietwo',
     ):
         cls = chip_match.AnnotMatch  # ibs.depc_annot.requestclass_dict['BC_DTW']
     else:
@@ -539,21 +545,11 @@ def review_graph_match_html(
     annot_uuid_2 = str(annot_uuid_2)
 
     embedded = dict(globals(), **locals())
-    return appf.template('turk', 'identification_insert', **embedded)
+    return appf.template('review', 'identification_insert', **embedded)
 
 
 @register_route('/test/review/query/chip/', methods=['GET'])
 def review_query_chips_test(**kwargs):
-    """
-    CommandLine:
-        python -m wbia.web.apis_query review_query_chips_test --show
-
-    Example:
-        >>> # SCRIPT
-        >>> import wbia
-        >>> web_ibs = wbia.opendb_bg_web(
-        >>>     browser=True, url_suffix='/test/review/query/chip/?__format__=true')
-    """
     ibs = current_app.ibs
 
     # the old block curvature dtw
@@ -568,6 +564,10 @@ def review_query_chips_test(**kwargs):
         query_config_dict = {'pipeline_root': 'CurvRankFinfindrHybridDorsal'}
     elif 'use_curvrank_fluke' in request.args:
         query_config_dict = {'pipeline_root': 'CurvRankFluke'}
+    elif 'use_curvrank_v2_dorsal' in request.args:
+        query_config_dict = {'pipeline_root': 'CurvRankTwoDorsal'}
+    elif 'use_curvrank_v2_fluke' in request.args:
+        query_config_dict = {'pipeline_root': 'CurvRankTwoFluke'}
     elif 'use_deepsense' in request.args:
         query_config_dict = {'pipeline_root': 'Deepsense'}
     elif 'use_finfindr' in request.args:
@@ -576,6 +576,8 @@ def review_query_chips_test(**kwargs):
         query_config_dict = {'pipeline_root': 'KaggleSeven'}
     elif 'use_pie' in request.args:
         query_config_dict = {'pipeline_root': 'Pie'}
+    elif 'use_pie_v2' in request.args:
+        query_config_dict = {'pipeline_root': 'PieTwo'}
     else:
         query_config_dict = {}
     result_dict = ibs.query_chips_test(query_config_dict=query_config_dict)
@@ -613,14 +615,23 @@ def review_query_chips_test(**kwargs):
 
 @register_ibs_method
 @register_api('/api/review/query/chip/best/', methods=['GET'])
-def review_query_chips_best(ibs, aid, **kwargs):
+def review_query_chips_best(ibs, aid, database_imgsetid=None, **kwargs):
     # from wbia.algo.hots import chip_match
 
     # query_config_dict = {}
 
     # Compile test data
     qaid_list = [aid]
-    daid_list = ibs.get_valid_aids()
+    if database_imgsetid is not None:
+        all_imgsetids = set(ibs.get_valid_imgsetids())
+        if database_imgsetid not in all_imgsetids:
+            database_imgsetid = None
+
+    if database_imgsetid is None:
+        daid_list = ibs.get_valid_aids()
+    else:
+        daid_list = ibs.get_imageset_aids(database_imgsetid)
+
     result_dict = ibs.query_chips_graph(qaid_list, daid_list, **kwargs)
 
     uuid = list(result_dict['cm_dict'].keys())[0]
@@ -628,11 +639,71 @@ def review_query_chips_best(ibs, aid, **kwargs):
 
     scores = result['name_score_list']
     names = result['unique_name_list']
-    best_index = np.argmax(scores)
 
-    best_name = names[best_index]
+    if len(scores) == 0:
+        response = {
+            'name': None,
+            'sex': None,
+            'age': None,
+            'extern': {
+                'reference': None,
+                'qannot_uuid': None,
+                'dannot_uuid': None,
+            },
+        }
+    else:
+        best_index = np.argmax(scores)
+        best_name = names[best_index]
+        best_nid = ibs.get_name_rowids_from_text(best_name)
+        best_sex = ibs.get_name_sex_text(best_nid)
+        best_age_list = ibs.get_name_age_months_est_min(best_nid)
+        best_age_list = [
+            int(best_age)
+            for best_age in best_age_list
+            if best_age is not None and isinstance(best_age, int)
+        ]
+        best_age = min(best_age_list)
 
-    return best_name
+        if best_age in [0, 3, 6]:
+            best_age_str = 'Newborn'
+        elif best_age in [12]:
+            best_age_str = 'Yearling'
+        elif best_age in [24]:
+            best_age_str = '2-Year-Old'
+        elif best_age in [36]:
+            best_age_str = 'Adult'
+        else:
+            best_age_str = 'Unknown'
+
+        # ut.embed()
+        dannot_score_list = result['annot_score_list']
+        dannot_uuid_list = result['dannot_uuid_list']
+        dannot_flag_list = result['dannot_extern_list']
+        daid_list = ibs.get_annot_aids_from_uuid(dannot_uuid_list)
+        zipped = zip(dannot_score_list, daid_list, dannot_uuid_list, dannot_flag_list)
+        zipped = sorted(list(zipped), reverse=True)
+
+        aid_set = set(ibs.get_name_aids(best_nid))
+        dannot_uuid = None
+        for item in zipped:
+            score, daid, dannot_uuid_local, flag = item
+            if flag and daid in aid_set:
+                dannot_uuid = dannot_uuid_local
+                break
+        assert dannot_uuid is not None
+
+        response = {
+            'name': best_name,
+            'sex': best_sex.title(),
+            'age': best_age_str,
+            'extern': {
+                'reference': result['dannot_extern_reference'],
+                'qannot_uuid': str(result['qannot_uuid']),
+                'dannot_uuid': str(dannot_uuid),
+            },
+        }
+
+    return response
 
     # review_pair = result_dict['inference_dict']['annot_pair_dict']['review_pair_list'][0]
 
@@ -762,6 +833,24 @@ def query_chips_graph_complete(ibs, aid_list, query_config_dict={}, k=5, **kwarg
     return result_dict
 
 
+@register_ibs_method
+def log_render_status(ibs, *args):
+    import os
+
+    json_log_path = ibs.get_logdir_local()
+    json_log_filename = 'render.log'
+    json_log_filepath = os.path.join(json_log_path, json_log_filename)
+    logger.info('Logging renders added to: %r' % (json_log_filepath,))
+
+    try:
+        with open(json_log_filepath, 'a') as json_log_file:
+            line = ','.join(['%s' % (arg,) for arg in args])
+            line = '%s\n' % (line,)
+            json_log_file.write(line)
+    except Exception:
+        logger.info('WRITE RENDER.LOG FAILED')
+
+
 @register_ibs_method
 @register_api('/api/query/graph/', methods=['GET', 'POST'])
 def query_chips_graph(
@@ -772,7 +861,7 @@ def query_chips_graph(
     query_config_dict={},
     echo_query_params=True,
     cache_images=True,
-    n=16,
+    n=20,
     view_orientation='horizontal',
     return_summary=True,
     **kwargs,
@@ -963,6 +1052,20 @@ def query_chips_graph(
                     except Exception:
                         filepath_matches = None
                         extern_flag = 'error'
+                    log_render_status(
+                        ibs,
+                        cm.qaid,
+                        daid,
+                        quuid,
+                        duuid,
+                        cm,
+                        qreq_,
+                        view_orientation,
+                        True,
+                        False,
+                        filepath_matches,
+                        extern_flag,
+                    )
                     try:
                         _, filepath_heatmask = ensure_review_image(
                             ibs,
@@ -976,6 +1079,20 @@ def query_chips_graph(
                     except Exception:
                         filepath_heatmask = None
                         extern_flag = 'error'
+                    log_render_status(
+                        ibs,
+                        cm.qaid,
+                        daid,
+                        quuid,
+                        duuid,
+                        cm,
+                        qreq_,
+                        view_orientation,
+                        False,
+                        True,
+                        filepath_heatmask,
+                        extern_flag,
+                    )
                     try:
                         _, filepath_clean = ensure_review_image(
                             ibs,
@@ -989,6 +1106,20 @@ def query_chips_graph(
                     except Exception:
                         filepath_clean = None
                         extern_flag = 'error'
+                    log_render_status(
+                        ibs,
+                        cm.qaid,
+                        daid,
+                        quuid,
+                        duuid,
+                        cm,
+                        qreq_,
+                        view_orientation,
+                        False,
+                        False,
+                        filepath_clean,
+                        extern_flag,
+                    )
 
                     if filepath_matches is not None:
                         args = (
@@ -1106,7 +1237,6 @@ def query_chips_graph_match_thumb(
     from PIL import Image  # NOQA
     import vtool as vt
     from io import BytesIO
-    from six.moves import cStringIO as StringIO
     from flask import send_file
 
     ibs = current_app.ibs
@@ -1165,10 +1295,7 @@ def query_chips_graph_match_thumb(
 
     # Encode image
     image_pil = Image.fromarray(image)
-    if six.PY2:
-        img_io = StringIO()
-    else:
-        img_io = BytesIO()
+    img_io = BytesIO()
     image_pil.save(img_io, 'JPEG', quality=100)
     img_io.seek(0)
     return send_file(img_io, mimetype='image/jpeg')
@@ -1325,7 +1452,7 @@ def get_graph_client_query_chips_graph_v2(ibs, graph_uuid):
     graph_client = current_app.GRAPH_CLIENT_DICT.get(graph_uuid, None)
     # We could be redirecting to a newer graph_client
     graph_uuid_chain = [graph_uuid]
-    while isinstance(graph_client, six.string_types):
+    while isinstance(graph_client, str):
         graph_uuid_chain.append(graph_client)
         graph_client = current_app.GRAPH_CLIENT_DICT.get(graph_client, None)
     if graph_client is None:
@@ -1360,7 +1487,7 @@ def ensure_review_image_v2(
 def query_graph_v2_callback(graph_client, callback_type):
     from wbia.web.graph_server import ut_to_json_encode
 
-    assert callback_type in ['review', 'finished']
+    assert callback_type in ['review', 'finished', 'error']
     callback_tuple = graph_client.callbacks.get(callback_type, None)
     if callback_tuple is not None:
         callback_url, callback_method = callback_tuple
@@ -1390,6 +1517,7 @@ def query_chips_graph_v2(
     finished_callback_url=None,
     finished_callback_method='POST',
     creation_imageset_rowid_list=None,
+    backend='graph_algorithm',
     **kwargs,
 ):
     """
@@ -1398,8 +1526,8 @@ def query_chips_graph_v2(
 
         python -m wbia reset_mtest_graph
 
-        python -m wbia --db PZ_MTEST --web --browser --url=/turk/identification/hardcase/
-        python -m wbia --db PZ_MTEST --web --browser --url=/turk/identification/graph/
+        python -m wbia --db PZ_MTEST --web --browser --url=/review/identification/hardcase/
+        python -m wbia --db PZ_MTEST --web --browser --url=/review/identification/graph/
 
     Example:
         >>> # xdoctest: +REQUIRES(--web-tests)
@@ -1408,13 +1536,12 @@ def query_chips_graph_v2(
         >>> # Open local instance
         >>> ibs = wbia.opendb('PZ_MTEST')
         >>> uuid_list = ibs.annots().uuids[0:10]
-        >>> # Start up the web instance
-        >>> web_ibs = wbia.opendb_bg_web(db='PZ_MTEST', web=True, browser=False)
         >>> data = dict(annot_uuid_list=uuid_list)
-        >>> resp = web_ibs.send_wbia_request('/api/query/graph/v2/', **data)
-        >>> print('resp = %r' % (resp,))
-        >>> #cmdict_list = json_dict['response']
-        >>> #assert 'score_list' in cmdict_list[0]
+        >>> # Start up the web instance
+        >>> with wbia.opendb_with_web(db='PZ_MTEST') as (ibs, client):
+        ...     resp = client.post('/api/query/graph/v2/', data=data)
+        >>> resp.json
+        {'status': {'success': False, 'code': 608, 'message': 'Invalid image and/or annotation UUIDs (0, 1)', 'cache': -1}, 'response': {'invalid_image_uuid_list': [], 'invalid_annot_uuid_list': [[0, '...']]}}
 
     Example:
         >>> # DEBUG_SCRIPT
@@ -1432,7 +1559,14 @@ def query_chips_graph_v2(
         >>> # Reset context
         >>> query_chips_graph_v2.__globals__['current_app'] = old
     """
-    from wbia.web.graph_server import GraphClient
+
+    backend = backend.lower()
+    if backend in ['graph_algorithm', 'graph', 'ga']:
+        from wbia.web.graph_server import GraphAlgorithmClient as GraphClient
+    elif backend in ['lca', 'clusters']:
+        from wbia_lca._plugin import LCAClient as GraphClient
+    else:
+        raise NotImplementedError('Requested backend %r not supported' % (backend,))
 
     logger.info('[apis_query] Creating GraphClient')
 
@@ -1464,11 +1598,6 @@ def query_chips_graph_v2(
             'review': (review_callback_url, review_callback_method),
             'finished': (finished_callback_url, finished_callback_method),
         }
-        graph_client = GraphClient(graph_uuid, callbacks=callback_dict, autoinit=True)
-
-        if creation_imageset_rowid_list is not None:
-            graph_client.imagesets = creation_imageset_rowid_list
-        graph_client.aids = aid_list
 
         config = {
             'manual.n_peek': GRAPH_CLIENT_PEEK,
@@ -1478,8 +1607,18 @@ def query_chips_graph_v2(
             'algo.quickstart': False,
         }
         config.update(query_config_dict)
-        logger.info('[apis_query] graph_client.config = {}'.format(ut.repr3(config)))
-        graph_client.config = config
+        logger.info(
+            '[apis_query] graph_client.actor_config = {}'.format(ut.repr3(config))
+        )
+
+        graph_client = GraphClient(
+            aids=aid_list,
+            actor_config=config,
+            imagesets=creation_imageset_rowid_list,
+            graph_uuid=graph_uuid,
+            callbacks=callback_dict,
+            autoinit=True,
+        )
 
         # Ensure no race-conditions
         current_app.GRAPH_CLIENT_DICT[graph_uuid] = graph_client
@@ -1489,30 +1628,27 @@ def query_chips_graph_v2(
             'action': 'start',
             'dbdir': ibs.dbdir,
             'aids': graph_client.aids,
-            'config': graph_client.config,
+            'config': graph_client.actor_config,
+            'graph_uuid': graph_uuid,
         }
         future = graph_client.post(payload)
         future.result()  # Guarantee that this has happened before calling refresh
 
-        f2 = graph_client.post({'action': 'latest_logs'})
-        f2.graph_client = graph_client
-        f2.add_done_callback(query_graph_v2_latest_logs)
+        future = graph_client.post({'action': 'logs'})
+        future.graph_client = graph_client
+        future.add_done_callback(query_graph_v2_latest_logs)
 
-        # Start (create the Graph Inference object)
-        payload = {
-            'action': 'get_feat_extractor',
-        }
-        future = graph_client.post(payload)
-        graph_client.extr = future.result()
+        # Refresh metadata (place to store information provided by the actor)
+        graph_client.refresh_metadata()
 
         # Start main loop
-        future = graph_client.post({'action': 'continue_review'})
+        future = graph_client.post({'action': 'resume'})
         future.graph_client = graph_client
         future.add_done_callback(query_graph_v2_on_request_review)
 
-        f2 = graph_client.post({'action': 'latest_logs'})
-        f2.graph_client = graph_client
-        f2.add_done_callback(query_graph_v2_latest_logs)
+        future = graph_client.post({'action': 'logs'})
+        future.graph_client = graph_client
+        future.add_done_callback(query_graph_v2_latest_logs)
 
     return graph_uuid
 
@@ -1584,10 +1720,9 @@ def review_graph_match_config_v2(
     logger.info('Sampled edge %r with priority %0.02f' % args)
     logger.info('Data: ' + ut.repr4(data_dict))
 
+    extr_ = graph_client.metadata.get('extr', None)
     feat_extract_config = {
-        'match_config': (
-            {} if graph_client.extr is None else graph_client.extr.match_config
-        )
+        'match_config': {} if extr_ is None else extr_.match_config,
     }
     extr = pairfeat.PairwiseFeatureExtractor(ibs, config=feat_extract_config)
 
@@ -1705,7 +1840,7 @@ def review_graph_match_html_v2(
             EMBEDDED_JAVASCRIPT += json_template_fmtstr % (json_file.read(),)
 
     embedded = dict(globals(), **locals())
-    return appf.template('turk', 'identification_insert', **embedded)
+    return appf.template('review', 'identification_insert', **embedded)
 
 
 @register_api('/api/status/query/graph/v2/', methods=['GET'], __api_plural_check__=False)
@@ -1762,7 +1897,7 @@ def process_graph_match_html_v2(ibs, graph_uuid, **kwargs):
         ibs.set_annot_metadata([aid], [metadata_dict])
 
         payload = {
-            'action': 'remove_annots',
+            'action': 'remove_aids',
             'aids': [aid],
         }
     elif decision in ['excludeleft', 'excluderight']:
@@ -1774,12 +1909,12 @@ def process_graph_match_html_v2(ibs, graph_uuid, **kwargs):
         ibs.set_annot_metadata([aid], [metadata_dict])
 
         payload = {
-            'action': 'remove_annots',
+            'action': 'remove_aids',
             'aids': [aid],
         }
     else:
         payload = {
-            'action': 'add_feedback',
+            'action': 'feedback',
             'edge': edge,
             'evidence_decision': decision,
             # TODO: meta_decision should come from the html resp.  When generating
@@ -1799,17 +1934,17 @@ def process_graph_match_html_v2(ibs, graph_uuid, **kwargs):
     logger.info(ut.repr4(payload))
     graph_client.post(payload)
 
-    # Clean any old continue_reviews
+    # Clean any old resumes
     graph_client.cleanup()
 
     # Continue review
-    future = graph_client.post({'action': 'continue_review'})
+    future = graph_client.post({'action': 'resume'})
     future.graph_client = graph_client
     future.add_done_callback(query_graph_v2_on_request_review)
 
-    f2 = graph_client.post({'action': 'latest_logs'})
-    f2.graph_client = graph_client
-    f2.add_done_callback(query_graph_v2_latest_logs)
+    future = graph_client.post({'action': 'logs'})
+    future.graph_client = graph_client
+    future.add_done_callback(query_graph_v2_latest_logs)
     return (
         annot_uuid_1,
         annot_uuid_2,
@@ -1819,66 +1954,8 @@ def process_graph_match_html_v2(ibs, graph_uuid, **kwargs):
 @register_ibs_method
 @register_api('/api/query/graph/v2/', methods=['GET'])
 def sync_query_chips_graph_v2(ibs, graph_uuid):
-    import wbia
-
     graph_client, _ = ibs.get_graph_client_query_chips_graph_v2(graph_uuid)
-
-    # Create the AnnotInference
-    infr = wbia.AnnotInference(ibs=ibs, aids=graph_client.aids, autoinit=True)
-    for key in graph_client.config:
-        infr.params[key] = graph_client.config[key]
-    infr.reset_feedback('staging', apply=True)
-
-    infr.relabel_using_reviews(rectify=True)
-    edge_delta_df = infr.match_state_delta(old='annotmatch', new='all')
-    name_delta_df = infr.get_wbia_name_delta()
-
-    ############################################################################
-
-    col_list = list(edge_delta_df.columns)
-    match_aid_edge_list = list(edge_delta_df.index)
-    match_aid1_list = ut.take_column(match_aid_edge_list, 0)
-    match_aid2_list = ut.take_column(match_aid_edge_list, 1)
-    match_annot_uuid1_list = ibs.get_annot_uuids(match_aid1_list)
-    match_annot_uuid2_list = ibs.get_annot_uuids(match_aid2_list)
-    match_annot_uuid_edge_list = list(zip(match_annot_uuid1_list, match_annot_uuid2_list))
-
-    zipped = list(zip(*(list(edge_delta_df[col]) for col in col_list)))
-
-    match_list = []
-    for match_annot_uuid_edge, zipped_ in list(zip(match_annot_uuid_edge_list, zipped)):
-        match_dict = {
-            'edge': match_annot_uuid_edge,
-        }
-        for index, col in enumerate(col_list):
-            match_dict[col] = zipped_[index]
-        match_list.append(match_dict)
-
-    ############################################################################
-
-    col_list = list(name_delta_df.columns)
-    name_aid_list = list(name_delta_df.index)
-    name_annot_uuid_list = ibs.get_annot_uuids(name_aid_list)
-    old_name_list = list(name_delta_df['old_name'])
-    new_name_list = list(name_delta_df['new_name'])
-    zipped = list(zip(name_annot_uuid_list, old_name_list, new_name_list))
-    name_dict = {
-        str(name_annot_uuid): {'old': old_name, 'new': new_name}
-        for name_annot_uuid, old_name, new_name in zipped
-    }
-
-    ############################################################################
-
-    ret_dict = {
-        'match_list': match_list,
-        'name_dict': name_dict,
-    }
-
-    infr.write_wbia_staging_feedback()
-    infr.write_wbia_annotmatch_feedback(edge_delta_df)
-    infr.write_wbia_name_assignment(name_delta_df)
-    edge_delta_df.reset_index()
-
+    ret_dict = graph_client.sync(ibs)
     return ret_dict
 
 
@@ -1907,7 +1984,7 @@ def add_annots_query_chips_graph_v2(ibs, graph_uuid, annot_uuid_list):
     graph_client.graph_uuid = graph_uuid_
 
     payload = {
-        'action': 'add_annots',
+        'action': 'add_aids',
         'dbdir': ibs.dbdir,
         'aids': aid_list,
     }
@@ -1915,7 +1992,7 @@ def add_annots_query_chips_graph_v2(ibs, graph_uuid, annot_uuid_list):
     future.result()  # Guarantee that this has happened before calling refresh
 
     # Start main loop
-    future = graph_client.post({'action': 'continue_review'})
+    future = graph_client.post({'action': 'resume'})
     future.graph_client = graph_client
     future.add_done_callback(query_graph_v2_on_request_review)
 
@@ -1936,7 +2013,7 @@ def remove_annots_query_chips_graph_v2(ibs, graph_uuid, annot_uuid_list):
     graph_client.graph_uuid = graph_uuid_
 
     payload = {
-        'action': 'remove_annots',
+        'action': 'remove_aids',
         'dbdir': ibs.dbdir,
         'aids': aid_list,
     }
@@ -1944,7 +2021,7 @@ def remove_annots_query_chips_graph_v2(ibs, graph_uuid, annot_uuid_list):
     future.result()  # Guarantee that this has happened before calling refresh
 
     # Start main loop
-    future = graph_client.post({'action': 'continue_review'})
+    future = graph_client.post({'action': 'resume'})
     future.graph_client = graph_client
     future.add_done_callback(query_graph_v2_on_request_review)
 
@@ -1969,20 +2046,33 @@ def delete_query_chips_graph_v2(ibs, graph_uuid):
 def query_graph_v2_latest_logs(future):
     if not future.cancelled():
         logs = future.result()
-        logger.info('--- <LOG DUMP> ---')
-        for msg, color in logs:
-            ut.cprint('[web.infr] ' + msg, color)
-        logger.info('--- <\\LOG DUMP> ---')
+        if logs is not None:
+            logger.info('--- <LOG DUMP> ---')
+            for msg, color in logs:
+                ut.cprint('[web.infr] ' + msg, color)
+            logger.info('--- <\\LOG DUMP> ---')
 
 
 def query_graph_v2_on_request_review(future):
     if not future.cancelled():
         graph_client = future.graph_client
-        data_list = future.result()
-        if data_list is not None:
-            graph_client.update(data_list)
-            callback_type = 'review'
-        else:
-            graph_client.update(None)
-            callback_type = 'finished'
+        try:
+            data_list = future.result()
+            finished = graph_client.update(data_list)
+            callback_type = 'finished' if finished else 'review'
+        except ValueError:
+            callback_type = 'error'
         query_graph_v2_callback(graph_client, callback_type)
+
+
+if __name__ == '__main__':
+    r"""
+    CommandLine:
+        python -m wbia.algo.detect.train_assigner --allexamples
+    """
+    import multiprocessing
+
+    multiprocessing.freeze_support()  # for win32
+    import utool as ut  # NOQA
+
+    ut.doctest_funcs()
