@@ -17,9 +17,6 @@ import utool as ut
 logger = logging.getLogger('wbia')
 
 
-logger.setLevel(logging.INFO)
-
-
 try:
     try:
         from werkzeug.wsgi import DispatcherMiddleware
@@ -37,14 +34,13 @@ def tst_html_error():
     r"""
     This test will show what our current errors look like
 
-    CommandLine:
-        python -m wbia.web.app --exec-tst_html_error
-
     Example:
-        >>> # DISABLE_DOCTEST
-        >>> from wbia.web.app import *  # NOQA
         >>> import wbia
-        >>> web_ibs = wbia.opendb_bg_web(browser=True, start_job_queue=False, url_suffix='/api/image/imagesettext/?__format__=True')
+        >>> with wbia.opendb_with_web('testdb1') as (ibs, client):
+        ...     resp = client.get('/api/image/imagesettext/?__format__=True')
+        >>> print(resp)
+        <WrapperTestResponse streamed [500 INTERNAL SERVER ERROR]>
+
     """
     pass
 
@@ -165,7 +161,7 @@ def start_tornado(
             else:
                 raise RuntimeError(
                     (
-                        ('The specified IBEIS web port %d is not available, ' 'but %d is')
+                        ('The specified web port %d is not available, ' 'but %d is')
                         % (app.server_port, fallback_port)
                     )
                 )
@@ -177,6 +173,10 @@ def start_tornado(
             utool_logfile_handler = None
 
         if utool_logfile_handler is not None:
+            for handler in utool_logfile_handler.handlers:
+                if isinstance(handler, ut.CustomStreamHandler):
+                    utool_logfile_handler.removeHandler(handler)
+
             logger_list = []
             try:
                 logger_list += [
@@ -191,12 +191,13 @@ def start_tornado(
             except AttributeError:
                 pass
             logger_list += [
+                # logging.getLogger(),
                 logging.getLogger('concurrent'),
                 logging.getLogger('concurrent.futures'),
-                logging.getLogger('flask_cors.core'),
-                logging.getLogger('flask_cors'),
-                logging.getLogger('flask_cors.decorator'),
-                logging.getLogger('flask_cors.extension'),
+                # logging.getLogger('flask_cors.core'),
+                # logging.getLogger('flask_cors'),
+                # logging.getLogger('flask_cors.decorator'),
+                # logging.getLogger('flask_cors.extension'),
                 logging.getLogger('urllib3'),
                 logging.getLogger('requests'),
                 logging.getLogger('tornado'),
@@ -204,11 +205,14 @@ def start_tornado(
                 logging.getLogger('tornado.application'),
                 logging.getLogger('tornado.general'),
                 logging.getLogger('websocket'),
+                logging.getLogger('wbia'),
             ]
             for logger_ in logger_list:
                 logger_.setLevel(logging.INFO)
                 logger_.addHandler(utool_logfile_handler)
 
+        logging.basicConfig(level=logging.INFO)
+
         if start_web_loop:
             tornado.ioloop.IOLoop.instance().start()
 
