@@ -14,7 +14,6 @@ import utool as ut
 import pynmea2
 import simplejson as json
 import numpy as np
-import six
 
 (print, rrr, profile) = ut.inject2(__name__)
 logger = logging.getLogger('wbia')
@@ -23,11 +22,11 @@ DEFAULT_WEB_API_PORT = ut.get_argval('--port', type_=int, default=5000)
 TARGET_WIDTH = 1200.0
 TARGET_HEIGHT = 800.0
 PAGE_SIZE = 500
-VALID_TURK_MODES = [
-    ('turk_annotation', 'Annotation'),
-    ('turk_viewpoint', 'Viewpoint'),
-    ('turk_quality', 'Quality'),
-    ('turk_demographics', 'Demographics'),
+VALID_REVIEW_MODES = [
+    ('review_viewpoint2', 'Annotation'),
+    ('review_viewpoint3', 'Viewpoint'),
+    ('review_quality', 'Quality'),
+    ('review_demographics', 'Demographics'),
 ]
 
 
@@ -64,9 +63,10 @@ class NavbarClass(object):
             # ('view_names', 'Names'),
             ('view_graphs', 'Graphs'),
             # ('action', 'Action'),
-            ('turk', 'Turk'),
+            ('review', 'Review'),
             # ('view_experiments', 'Experiments'),
             ('view_jobs', 'Jobs'),
+            ('demo', 'Demo'),
             # ('api_root',  'API'),
             # ('group_review',  'Group Review'),
         ]
@@ -130,20 +130,13 @@ def embed_image_html(imgBGR, target_width=TARGET_WIDTH, target_height=TARGET_HEI
         imgBGR = _resize(imgBGR, t_height=target_height)
     imgRGB = cv2.cvtColor(imgBGR, cv2.COLOR_BGR2RGB)
     pil_img = Image.fromarray(imgRGB)
-    if six.PY2:
-        from six.moves import cStringIO as StringIO
+    import io
 
-        string_buf = StringIO()
-        pil_img.save(string_buf, format='jpeg')
-        data = string_buf.getvalue().encode('base64').replace('\n', '')
-    else:
-        import io
-
-        byte_buf = io.BytesIO()
-        pil_img.save(byte_buf, format='jpeg')
-        byte_buf.seek(0)
-        img_bytes = base64.b64encode(byte_buf.read())
-        data = img_bytes.decode('ascii')
+    byte_buf = io.BytesIO()
+    pil_img.save(byte_buf, format='jpeg')
+    byte_buf.seek(0)
+    img_bytes = base64.b64encode(byte_buf.read())
+    data = img_bytes.decode('ascii')
     return 'data:image/jpeg;base64,' + data
 
 
@@ -152,10 +145,7 @@ def check_valid_function_name(string):
 
 
 def encode_refer_url(decoded):
-    if six.PY2:
-        decoded = str(decoded)
-    else:
-        decoded = decoded.encode()
+    decoded = decoded.encode()
     encoded = base64.urlsafe_b64encode(decoded)
     encoded = encoded.decode('utf-8')
     return encoded
@@ -164,10 +154,9 @@ def encode_refer_url(decoded):
 def decode_refer_url(encoded):
     if len(encoded) == 0:
         return encoded
-    if six.PY3:
-        if encoded.startswith("b'"):
-            encoded = encoded[2:]
-            encoded = encoded[:-1]
+    if encoded.startswith("b'"):
+        encoded = encoded[2:]
+        encoded = encoded[:-1]
     encoded = str(encoded)
     decoded = base64.urlsafe_b64decode(encoded)
     decoded = decoded.decode('utf-8')
@@ -206,23 +195,23 @@ def template(template_directory=None, template_filename=None, **kwargs):
     # Update global args with the template's args
     _global_args = dict(global_args)
     _global_args.update(kwargs)
-    logger.info('[appfuncs] template()')
+    # logger.info('[appfuncs] template()')
     app = controller_inject.get_flask_app()
     # flask hates windows apparently
     template_ = template_.replace('\\', '/')
-    logger.info('[appfuncs.template] * app.template_folder = %r' % (app.template_folder,))
-    logger.info('[appfuncs.template] * template_directory = %r' % (template_directory,))
-    logger.info('[appfuncs.template] * template_filename = %r' % (template_filename,))
-    logger.info('[appfuncs.template] * template_ = %r' % (template_,))
+    # logger.info('[appfuncs.template] * app.template_folder = %r' % (app.template_folder,))
+    # logger.info('[appfuncs.template] * template_directory = %r' % (template_directory,))
+    # logger.info('[appfuncs.template] * template_filename = %r' % (template_filename,))
+    # logger.info('[appfuncs.template] * template_ = %r' % (template_,))
     try:
         ret = flask.render_template(template_, **_global_args)
         # ret = flask.render_template(full_template_fpath, **_global_args)
     except jinja2.exceptions.TemplateNotFound as ex:
         logger.info('Error template not found')
         full_template_fpath = join(app.template_folder, template_)
-        logger.info(
-            '[appfuncs.template] * full_template_fpath = %r' % (full_template_fpath,)
-        )
+        # logger.info(
+        #     '[appfuncs.template] * full_template_fpath = %r' % (full_template_fpath,)
+        # )
         ut.checkpath(full_template_fpath, verbose=True)
         ut.printex(ex, 'Template error in appfuncs', tb=True)
         raise
@@ -242,7 +231,7 @@ def send_csv_file(string, filename):
     return response
 
 
-def get_turk_image_args(is_reviewed_func):
+def get_review_image_args(is_reviewed_func):
     """
     Helper to return gids in an imageset or a group review
     """
@@ -279,7 +268,7 @@ def get_turk_image_args(is_reviewed_func):
     return gid_list, reviewed_list, imgsetid, progress, gid, previous
 
 
-def get_turk_annot_args(is_reviewed_func, speed_hack=False):
+def get_review_annot_args(is_reviewed_func, speed_hack=False):
     """
     Helper to return aids in an imageset or a group review
     """
