@@ -67,6 +67,7 @@ import flask
 from os.path import join, exists, abspath, splitext, basename
 from functools import partial
 from wbia.control import controller_inject
+from wbia.utils import call_houston
 import multiprocessing
 
 
@@ -83,7 +84,13 @@ ctx = zmq.Context.instance()
 
 # FIXME: needs to use correct number of ports
 URL = 'tcp://127.0.0.1'
-NUM_ENGINES = 1 if ut.get_argflag('--serial-job-lanes') else 2
+NUM_DEFAULT_ENGINES = ut.get_argval('--engine-lane-workers', int, 2)
+NUM_SLOW_ENGINES = ut.get_argval('--engine-slow-lane-workers', int, NUM_DEFAULT_ENGINES)
+NUM_FAST_ENGINES = ut.get_argval('--engine-fast-lane-workers', int, NUM_DEFAULT_ENGINES)
+NUM_ENGINES = {
+    'slow': NUM_SLOW_ENGINES,
+    'fast': NUM_FAST_ENGINES,
+}
 # VERBOSE_JOBS = (
 #     ut.get_argflag('--bg') or ut.get_argflag('--fg') or ut.get_argflag('--verbose-jobs')
 # )
@@ -131,6 +138,8 @@ def _get_engine_lock_paths(ibs):
 
 @register_ibs_method
 def retry_job(ibs, jobid):
+    from os.path import exists
+
     shelve_path = ibs.get_shelves_path()
     job_record_filename = '%s.pkl' % (jobid,)
     job_record_filepath = join(shelve_path, job_record_filename)
@@ -162,6 +171,7 @@ def initialize_job_manager(ibs):
 
     Example:
         >>> # DISABLE_DOCTEST
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
         >>> from wbia.web.job_engine import *  # NOQA
         >>> import wbia
         >>> ibs = wbia.opendb(defaultdb='testdb1')
@@ -174,24 +184,6 @@ def initialize_job_manager(ibs):
         >>> ibs.close_job_manager()
         >>> print('Closing success.')
 
-    Example:
-        >>> # xdoctest: +REQUIRES(--web-tests)
-        >>> from wbia.web.job_engine import *  # NOQA
-        >>> import wbia
-        >>> import requests
-        >>> with wbia.opendb_bg_web(db='testdb1', managed=True) as web_instance:
-        ...     web_port = ibs.get_web_port_via_scan()
-        ...     if web_port is None:
-        ...         raise ValueError('IA web server is not running on any expected port')
-        ...     baseurl = 'http://127.0.1.1:%s' % (web_port, )
-        ...     _payload = {'image_attrs_list': [], 'annot_attrs_list': []}
-        ...     payload = ut.map_dict_vals(ut.to_json, _payload)
-        ...     resp1 = requests.post(baseurl + '/api/test/helloworld/?f=b', data=payload)
-        ...     #resp2 = requests.post(baseurl + '/api/image/json/', data=payload)
-        ...     #print(resp2)
-        ...     #json_dict = resp2.json()
-        ...     #text = json_dict['response']
-        ...     #print(text)
     """
     ibs.job_manager = ut.DynStruct()
 
@@ -265,6 +257,7 @@ def get_job_id_list(ibs):
 
     Example:
         >>> # xdoctest: +REQUIRES(--web-tests)
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
         >>> from wbia.web.job_engine import *  # NOQA
         >>> import wbia
         >>> with wbia.opendb_bg_web('testdb1', managed=True) as web_ibs:  # , domain='http://52.33.105.88')
@@ -317,6 +310,7 @@ def get_job_status(ibs, jobid=None):
 
     Example:
         >>> # xdoctest: +REQUIRES(--web-tests)
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
         >>> from wbia.web.job_engine import *  # NOQA
         >>> import wbia
         >>> with wbia.opendb_bg_web('testdb1', managed=True) as web_ibs:  # , domain='http://52.33.105.88')
@@ -362,8 +356,10 @@ def get_job_metadata(ibs, jobid):
         python -m wbia.web.job_engine --exec-get_job_metadata:0 --fg
 
     Example:
+        >>> # xdoctest: +REQUIRES(--web-tests)
         >>> # xdoctest: +REQUIRES(--slow)
-        >>> # WEB_DOCTEST
+        >>> # xdoctest: +REQUIRES(--job-engine-tests)
+        >>> # xdoctest: +REQUIRES(--web-tests)
         >>> from wbia.web.job_engine import *  # NOQA
         >>> import wbia
         >>> with wbia.opendb_bg_web('testdb1', managed=True) as web_ibs:  # , domain='http://52.33.105.88')
@@ -486,7 +482,7 @@ class JobBackend(object):
         self.engine_lanes = [lane.lower() for lane in self.engine_lanes]
         assert 'slow' in self.engine_lanes
 
-        self.num_engines = {lane: NUM_ENGINES for lane in self.engine_lanes}
+        self.num_engines = {lane: NUM_ENGINES[lane] for lane in self.engine_lanes}
         self.engine_procs = None
         self.collect_queue_proc = None
         self.collect_proc = None
@@ -531,7 +527,7 @@ class JobBackend(object):
             print('Killed external procs')
 
     def _initialize_job_ports(self, use_static_ports=False, static_root=51381):
-        # _portgen = functools.partial(six.next, itertools.count(51381))
+        # _portgen = functools.partial(next, itertools.count(51381))
         key_list = [
             'collect_pull_url',
             'collect_push_url',
@@ -1034,7 +1030,9 @@ class JobInterface(object):
         action,
         callback_url=None,
         callback_method=None,
+        callback_detailed=False,
         lane='slow',
+        jobid=None,
         *args,
         **kwargs
     ):
@@ -1068,14 +1066,20 @@ class JobInterface(object):
             except RuntimeError:
                 pass
 
+            if jobid is not None:
+                assert isinstance(jobid, str)
+                jobid_ = uuid.UUID(jobid)
+                assert jobid_ is not None and isinstance(jobid_, uuid.UUID)
+
             engine_request = {
                 'action': action,
                 'args': args,
                 'kwargs': kwargs,
                 'callback_url': callback_url,
                 'callback_method': callback_method,
+                'callback_detailed': callback_detailed,
                 'request': request,
-                'restart_jobid': None,
+                'restart_jobid': jobid,
                 'restart_jobcounter': None,
                 'restart_received': None,
                 'lane': lane,
@@ -1087,7 +1091,11 @@ class JobInterface(object):
             jobiface.engine_recieve_socket.send_json(engine_request)
             reply_notify = jobiface.engine_recieve_socket.recv_json()
             print('reply_notify = %r' % (reply_notify,))
-            jobid = reply_notify['jobid']
+            jobid_ = reply_notify['jobid']
+
+            if jobid is not None:
+                assert jobid == jobid_
+            jobid = jobid_
 
             ibs = jobiface.ibs
             if ibs is not None:
@@ -1109,6 +1117,7 @@ class JobInterface(object):
             kwargs = None
             callback_url = None
             callback_method = None
+            callback_detailed = None
             request = None
             engine_request = None
 
@@ -1347,6 +1356,7 @@ def engine_queue_loop(port_dict, engine_lanes):
                     kwargs = engine_request['kwargs']
                     callback_url = engine_request['callback_url']
                     callback_method = engine_request['callback_method']
+                    callback_detailed = engine_request['callback_detailed']
                     request = engine_request['request']
                     restart_jobid = engine_request.get('restart_jobid', None)
                     restart_jobcounter = engine_request.get('restart_jobcounter', None)
@@ -1419,6 +1429,7 @@ def engine_queue_loop(port_dict, engine_lanes):
                             'kwargs': kwargs,
                             'callback_url': callback_url,
                             'callback_method': callback_method,
+                            'callback_detailed': callback_detailed,
                             'request': request,
                             'times': {
                                 'received': received,
@@ -1564,7 +1575,7 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
             print('connect collect_pull_url = %r' % (interface_collect_pull,))
             print('engine is initialized')
 
-        ibs = wbia.opendb(dbdir=dbdir, use_cache=False, web=False)
+        ibs = wbia.opendb(dbdir=dbdir, use_cache=False, web=False, daily_backup=False)
         update_proctitle('engine_loop.%s.%s' % (lane, id_), dbname=ibs.dbname)
 
         try:
@@ -1580,6 +1591,7 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
                     kwargs = engine_request['kwargs']
                     callback_url = engine_request['callback_url']
                     callback_method = engine_request['callback_method']
+                    callback_detailed = engine_request['callback_detailed']
                     lane_ = engine_request['lane']
 
                     if VERBOSE_JOBS:
@@ -1619,6 +1631,7 @@ def engine_loop(id_, port_dict, dbdir, containerized, lane):
                         'engine_result': engine_result,
                         'callback_url': callback_url,
                         'callback_method': callback_method,
+                        'callback_detailed': callback_detailed,
                     }
                     # if VERBOSE_JOBS:
                     print(
@@ -1769,7 +1782,7 @@ def collector_loop(port_dict, dbdir, containerized):
         if VERBOSE_JOBS:
             print('connect collect_push_url  = %r' % (port_dict['collect_push_url'],))
 
-        ibs = wbia.opendb(dbdir=dbdir, use_cache=False, web=False)
+        ibs = wbia.opendb(dbdir=dbdir, use_cache=False, web=False, daily_backup=False)
         update_proctitle('collector_loop', dbname=ibs.dbname)
 
         shelve_path = ibs.get_shelves_path()
@@ -1881,7 +1894,7 @@ def on_collect_request(
     status = collect_request.get('status', None)
 
     reply = {
-        'status': 'ok',
+        'status': status,
         'jobid': jobid,
     }
 
@@ -2043,6 +2056,7 @@ def on_collect_request(
         engine_result = collect_request.get('engine_result', None)
         callback_url = collect_request.get('callback_url', None)
         callback_method = collect_request.get('callback_method', None)
+        callback_detailed = collect_request.get('callback_detailed', False)
 
         # Get the engine result jobid
         jobid = engine_result.get('jobid', jobid)
@@ -2070,6 +2084,11 @@ def on_collect_request(
 
             try:
                 data_dict = {'jobid': jobid}
+                if callback_detailed:
+                    shelve_value = get_shelve_value(shelve_output_filepath, 'result')
+                    data_dict['status'] = shelve_value['exec_status']
+                    data_dict['json_result'] = ut.from_json(shelve_value['json_result'])
+                    shelve_value = None  # Release memory
                 args = (
                     callback_url,
                     callback_method,
@@ -2082,10 +2101,29 @@ def on_collect_request(
 
                 # Perform callback
                 if callback_method == 'POST':
+                    if callback_url.startswith('houston+'):
+                        # Remove houston+ from callback_url
+                        call_houston(
+                            callback_url[8:],
+                            method='POST',
+                            data=ut.to_json(data_dict),
+                            headers={'Content-Type': 'application/json'},
+                        )
                     response = requests.post(callback_url, data=data_dict)
                 elif callback_method == 'GET':
+                    if callback_url.startswith('houston+'):
+                        # Remove houston+ from callback_url
+                        call_houston(callback_url[8:], method='GET', params=data_dict)
                     response = requests.get(callback_url, params=data_dict)
                 elif callback_method == 'PUT':
+                    if callback_url.startswith('houston+'):
+                        # Remove houston+ from callback_url
+                        call_houston(
+                            callback_url[8:],
+                            method='PUT',
+                            data=ut.to_json(data_dict),
+                            headers={'Content-Type': 'application/json'},
+                        )
                     response = requests.put(callback_url, data=data_dict)
                 else:
                     raise RuntimeError()
